#<profile4xi profile = "02" />
# -------------------------------------------------------------------------------------------------
#<program4xi program = "queue4xi.py">
#<abstract4xi abstract = "provides class Queue4Xi"/>
#<refer4xi reference = "queues.py"/>
#<state4xi status = "ACK4tagging; ACK4moduletesting; NACK4systemtesting; [Rel 7.21]"/>
# -------------------------------------------------------------------------------------------------

# -------------------------------------------------------------------------------------------------
# Public API
# -------------------------------------------------------------------------------------------------
#<interface4xi interface = " 
__all__ = [ 'Queue4Xi' ]
#"
#/>

# -------------------------------------------------------------------------------------------------
# Standard Imports                          
# -------------------------------------------------------------------------------------------------
#<standardize4xi standard = "
import sys
import os
import threading
import collections
import time
import atexit
import weakref
import _thread
import _winapi
from queue import Empty, Full
#"
#/>


# -------------------------------------------------------------------------------------------------
# Multiprocessing Imports                          
# -------------------------------------------------------------------------------------------------
#<process4xi process = "
try:                             # Binary ones
    import _multiprocessing
except:
    pass
try:                             # Python ones
    from multiprocessing.queues import Queue
except:
    print("queue4xi.py: *** failed in from multiprocessing.queues import Queue ***")
try:                             # Python ones
    from multiprocessing.connection import Pipe
except:
    print("queue4xi.py: *** failed in from multiprocessing.connection import Pipe ***")
try:                             # Python ones
    from multiprocessing.synchronize import BoundedSemaphore
except:
    print("queue4xi.py: *** failed in from multiprocessing.synchronize import BoundedSemaphore ***")
try:                             # Python ones
    from multiprocessing.util import register_after_fork
except:
    print("queue4xi.py: *** failed in from multiprocessing.util import register_after_fork ***")   

#"
#/>

# -------------------------------------------------------------------------------------------------
# DragonXi imports                              
# -------------------------------------------------------------------------------------------------
#<dragonize4xi dragonization = "

from ace_object4xi import ace_object4xi

from assert_spawning4xi import assert_spawning4xi

from boundedsemaphore4xi import BoundedSemaphore4Xi

from condition4xi import Condition4Xi
import constant_family4xi
import constant_heap4xi
import constant_pool4xi

from constant_system4xi import ConstantSystem4Xi
from constant_system4xi import get_windows_system4xi

from constant_synchronize4xi import get_sem_value_max_synchronize4xi

from examine4xi import examine4xi

from finalize4xi import Finalize4Xi

from is_exiting4xi import is_exiting4xi
from is_exiting4xi import init_exiting4xi
from is_exiting4xi import set_exiting4xi
from is_exiting4xi import get_exiting4xi

from lock4xi import Lock4Xi

from pipe4xi import Pipe4Xi


from reason_object4xi import reason_object4xi
from register_after_fork4xi import register_after_fork4xi

from sense_object4xi import sense_object4xi
from timeout4xi import omega2timeout4xi
from print4xi import print4xi
from time4xi import time4xi    
#"
#/>


# -------------------------------------------------------------------------------------------------
# Global constants                            
# ------------------------------------------------------------------------------------------------
#<globalize4xi globalization = "
_sentinel = object()
#"
#/>
 
# =================================================================================================
#<class4xi class = "Queue4Xi" base = "object" child = "None" synopsis = "Queue services using a pipe, buffer and thread" usage = "
#
#     queue.py
#         inherited class JoinableQueue
#
# joinablequeue4xi.py:
#      SyncManager4Xi.register('JoinableQueue4Xi', queue.Queue)
#
#      return Queue4Xi.__getstate__(self) + (self._cond, self._unfinished_tasks)
#
# pool4xi.py:
#      self._taskqueue = Queue4Xi()    
#
# syncmanager4xi.py:
#      SyncManager4Xi.register('Queue4Xi', queue.Queue)
#
# __init__.py:
#      return Queue4Xi(maxsize)    
#"
#>
#<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
# =================================================================================================
class Queue4Xi(object):
    '''
    Queue4Xi class: Queue servoces using a pipe, buffer and thread
    '''
                                           
    # ---------------------------------------------------------------------------------------------
    # Public API of this class
    # ---------------------------------------------------------------------------------------------    
    #<expose4xi expose = "
    _exposed_ = ('join_thread',
                 'get_nowait', 'put_nowait', 'close',                 
                 'empty', 'full', 'cancel_join_thread',                 
                 'put', 'get', 'qsize',
                 'sense', 'reason', 'ace')          
    #"
    #/>
                                                                                                                                                                    
                                                                                                                                                                         
                                                                                                                                                                    
                                                                                                                                                                    
                                                                                                                                                                         
                                                                                                                                                                                                                                        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "init-of-Queue4Xi" usage = "initializes Queue4Xi">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/> 
    # ---------------------------------------------------------------------------------------------    
    def __init__(self, maxsize=0):
        '''
        Queue4Xi method __init__ method initializes Queue4Xi
        '''
        
        
        # -----------------------------------------------------------------------------------------
        # (Step 1/11) - OK
        # -----------------------------------------------------------------------------------------
        class2print = "Queue4Xi"
        method2print = "__init__"

        
        message2print = "{(Step 1/11a) started" + "; init-of-Queue4Xi-started: " + time4xi() + "}"  
        print4xi(class2print, method2print, message2print)   
        # 05:46:47 01/22/13 Pacific Standard Time
        
        message2print = "{(Step 1/11b) borning" + "; queue2xi-of-Queue4Xi-borning: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)       
        # 05:46:47 01/22/13 Pacific Standard Time
        
        message2print = "{(Step 1/11c) inheriting" + "; object-inheriting-by-queue2xi-of-Queue4Xi: " + str(object)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
        # <class 'object'>
                        
        message2print = "{(Step 1/11d) passed" + "; maxsize-passed-to-init-of-Queue4Xi: " + str(maxsize) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        # 0
        

        if examine4xi(class2print, method2print):
        
            # -------------------------------------------------------------------------------------    
            # OK StepOriginal
            # -------------------------------------------------------------------------------------             
            message2print = "{(StepOriginal) calling" + "; Queue-init-calling-by-init-of-Queue4Xi: " + str(Queue.__init__) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)       

            Queue.__init__(self, maxsize)
        
        else:
            hyprid2use = False
            if hyprid2use is True:
                message2print = "{(Step 1/11e) used" + "; hyprid2use-used-by-init-of-Queue4Xi: " + str(hyprid2use)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)
                # 
                if maxsize <= 0:
                    maxsize = _multiprocessing.SemLock.SEM_VALUE_MAX
                self._maxsize = maxsize
                self._reader, self._writer = Pipe4Xi(duplex=False)
                self._rlock = Lock()
                self._opid = os.getpid()
                if sys.platform == 'win32':
                    self._wlock = None
                else:
                    self._wlock = Lock4Xi()
                self._sem = BoundedSemaphore4Xi(maxsize)
                # For use by concurrent.futures
                self._ignore_epipe = False
        
                self._after_fork()
        
                if sys.platform != 'win32':
                    register_after_fork(self, Queue4Xi._after_fork)
                    
                message2print = "{(Step 1/11f) performed" + "; hyprid2use-performed-by-init-of-Queue4Xi: " + str(hyprid2use)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)
                # 
            else:
             
                # -----------------------------------------------------------------------------------------
                # (Step 2/11) - OK
                # -----------------------------------------------------------------------------------------        
                csys2xi = ConstantSystem4Xi()
                
                message2print = "{(Step 2/11a) got" + "; csys2xi-got-by-init-of-Queue4Xi: " + str(csys2xi)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)
                # <constant_system4xi.ConstantSystem4Xi object at 0x00000000037B1908>
                                
                
                                
                # -----------------------------------------------------------------------------------------
                # (Step 3/11) - OK
                # -----------------------------------------------------------------------------------------        
                if maxsize <= 0:
                    maxsize = get_sem_value_max_synchronize4xi()
    
                    message2print = "{(Step 3/11a) set" + "; maxsize-set-by-init-of-Queue4Xi to: " + str(maxsize)  + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)    
                    # 2147483647
                    
                                     
                                                                
                self._maxsize = maxsize
        
                message2print = "{(Step 3/11b) set" + "; maxsize-of-queue2xi-set-by-init-of-Queue4Xi to: " + str(self._maxsize)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)    
                # 2147483647
                    
                    
                
                # -----------------------------------------------------------------------------------------
                # (Step 4/11) - OK
                # -----------------------------------------------------------------------------------------        
                
                message2print = "{(Step 4/11a) calling" + "; Pipe4Xi-calling-by-init-of-Queue4Xi: " + str(Pipe4Xi) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)       
                # <function Pipe4Xi at 0x00000000036537B8>    
                    
       
                self._reader, self._writer = Pipe4Xi(duplex=False)  
                
                message2print = "{(Step 4/11b) set" + "; reader-of-queue2xi-set-by-init-of-Queue4Xi: " + str(self._reader)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)
                # <pipeconnection4xi.PipeConnection4Xi object at 0x00000000037B1518>
                            
                message2print = "{(Step 4/11c) set" + "; writer-of-queue2xi-set-by-init-of-Queue4Xi: " + str(self._writer)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)
                # <pipeconnection4xi.PipeConnection4Xi object at 0x00000000037B1630>
                
                # -----------------------------------------------------------------------------------------
                # (Step 5/11) - OK
                # -----------------------------------------------------------------------------------------        
                self._rlock = Lock4Xi()
                
                message2print = "{(Step 5/11) set" + "; rlock-of-queue2xi-set-by-init-of-Queue4Xi to: " + str(self._rlock)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)    
                # <Lock(owner=None)>
    
                # -----------------------------------------------------------------------------------------
                # (Step 6/11) - OK
                # -----------------------------------------------------------------------------------------        
                self._opid = os.getpid()
        
                message2print = "{(Step 6/11) set" + "; opid-of-queue2xi-set-by-init-of-Queue4Xi to: " + str(self._opid)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)    
                # 5792
                    
                
                # -----------------------------------------------------------------------------------------
                # (Step 7/11) - OK
                # -----------------------------------------------------------------------------------------        
                if sys.platform == get_windows_system4xi():
                    self._wlock = None
                    
                    message2print = "{(Step 7/11a) set" + "; wlock-of-queue2xi-set-by-init-of-Queue4Xi to: " + str(self._wlock)  + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)    
                    # None            
                                    
                else:
                    self._wlock = Lock4Xi()
                    
                    
                    message2print = "{(Step 7/11b) set" + "; wlock-of-queue2xi-set-by-init-of-Queue4Xi to: " + str(self._wlock)  + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)    
                   
    
                
                
                # -----------------------------------------------------------------------------------------
                # (Step 8/11) - OK
                # -----------------------------------------------------------------------------------------        
                message2print = "{(Step 8/11a) passing" + "; maxsize-passing-to-BoundedSemaphore4Xi-by-init-of-Queue4Xi: " + str(maxsize) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)            
                # 2147483647
                
                self._sem = BoundedSemaphore4Xi(maxsize)
                
                message2print = "{(Step 8/11b) set" + "; sem-of-queue2xi-set-by-init-of-Queue4Xi to: " + str(self._sem)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)    
                # <BoundedSemaphore4Xi(value=1, maxvalue=2147483647)> 
                    
                
                # -----------------------------------------------------------------------------------------
                # (Step 9/11) - NEW
                # -----------------------------------------------------------------------------------------
                
                # For use by concurrent.futures
                self._ignore_epipe = False
                
                
                message2print = "{(Step 9/11a) set" + "; ignore-epipe-of-queue2xi-set-by-init-of-Queue4Xi to: " + str(self._ignore_epipe)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)    
                # False 
                
                self._after_fork()
        
                message2print = "{(Step 9/11b) performed" + "; after-fork-of-queue2xi-performed-by-init-of-Queue4Xi: " + str(self._after_fork) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)             
                # <bound method Queue4Xi._after_fork of <queue4xi.Queue4Xi object at 0x00000000037B16A0>>
                
                
                # -----------------------------------------------------------------------------------------
                # (Step 10/11) - OK
                # -----------------------------------------------------------------------------------------
                if sys.platform != csys2xi.get_windows():
                    
                    message2print = "{(Step 10/11a) passing" + "; Queue4Xi-after-fork-passing-to-register-after-fork4xi-by-init-of-Queue4Xi: " + str(Queue4Xi._after_fork) + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)            
                    
    
                    register_after_fork4xi(self, Queue4Xi._after_fork) 
                       
                    message2print = "{(Step 10/11a) performed" + ";  register-after-fork4xi-performed-by-init-of-Queue4Xi: " + str( register_after_fork4xi) + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)             
                                
                # -----------------------------------------------------------------------------------------
                # (Step 11/11) - OK
                # -----------------------------------------------------------------------------------------           
                message2print = "{(Step 11/11a) activated" + "; queue2xi-of-Queue4Xi-activated: " + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)  
                # 05:46:47 01/22/13 Pacific Standard Time
            
                message2print = "{(Step 11/11b) inherited" + "; object-inherited-by-queue2xi-of-Queue4Xi: " + str(object)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)         
                # <class 'object'>
                                       
                message2print = "{(Step 11/11c) returning" + "; init-of-Queue4Xi-returning: " + time4xi() + "}" 
                print4xi(class2print, method2print, message2print) 
                # 05:46:47 01/22/13 Pacific Standard Time
                 
                
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------               
                
        return
                                     
            
    #</methodize4xi>
                
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "getstate-of-Queue4Xi" usage = "
    #    returns queue state
    #    pool.py
    #          return Queue.__getstate__(self) + (self._cond, self._unfinished_tasks)
    #
    #">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/> 
    # ---------------------------------------------------------------------------------------------  
    def __getstate__(self):
        '''
        Queue4Xi method __getstate__ returns queue state
        '''
        # -----------------------------------------------------------------------------------------    
        # 
        # -----------------------------------------------------------------------------------------          
        class2print = "Queue4Xi"
        method2print = "__getstate__"
        
        message2print = "{started" + "; getstate-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        # 00:46:47 01/09/13 Pacific Standard Time
                        
        # -----------------------------------------------------------------------------------------    
        # 
        # -----------------------------------------------------------------------------------------          
        if examine4xi(class2print, method2print):
        
            # -------------------------------------------------------------------------------------    
            # StepOriginal
            # -------------------------------------------------------------------------------------             
            message2print = "{(StepOriginal) returning" + "; Queue-getstate-function-returning-by-getstate-of-Queue4Xi: " + str(Queue.__getstate__) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)  
                
            
            return Queue.__getstate__(self)
        
        else:            
            # -----------------------------------------------------------------------------------------    
            # (Step 1/2)
            # -----------------------------------------------------------------------------------------                 
            
            assert_spawning4xi(self)     #dragonized - does not raise exception but allows to try returning
            
            message2print = "{(Step 1/1a) performed" + "; assert-spawning4xi-performed-by-getstate-of-Queue4Xi: " + str(assert_spawning4xi) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
            # <function assert_spawning4xi at 0x000000000371F840>
                        
            # -----------------------------------------------------------------------------------------    
            # (Step 2/2) - NEW
            # -----------------------------------------------------------------------------------------                 
            message2print = "{(Step 2/2a) returning" + "; ignore-epipe-of-queue2xi-returning-by-getstate-of-Queue4Xi: " + str(self._ignore_epipe) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)    
            # False
                                     
            message2print = "{(Step 2/2b) returning" + "; maxsize-of-queue2xi-returning-by-getstate-of-Queue4Xi: " + str(self._maxsize) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)    
            # 2147483647
                            
            message2print = "{(Step 2/2c) returning" + "; reader-of-queue2xi-returning-by-getstate-of-Queue4Xi: " + str(self._reader) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)    
            # <pipeconnection4xi.PipeConnection4Xi object at 0x0000000003885278>
                            
            message2print = "{(Step 2/2d) returning" + "; writer-of-queue2xi-returning-by-getstate-of-Queue4Xi: " + str(self._writer) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)    
            # <pipeconnection4xi.PipeConnection4Xi object at 0x00000000038AFCC0>
                            
            message2print = "{(Step 2/2e) returning" + "; rlock-of-queue2xi-returning-by-getstate-of-Queue4Xi: " + str(self._rlock) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)    
            # <Lock(owner=None)>
                            
            message2print = "{(Step 2/2f) returning" + "; wlock-of-queue2xi-returning-by-getstate-of-Queue4Xi: " + str(self._wlock) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)    
            # None
                            
            message2print = "{(Step 2/2g) returning" + "; sem-of-queue2xi-returning-by-getstate-of-Queue4Xi: " + str(self._sem) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)    
            # <BoundedSemaphore4Xi(value=1, maxvalue=2147483647)>
                            
            message2print = "{(Step 2/2h) returning" + "; opid-of-queue2xi-returning-by-getstate-of-Queue4Xi: " + str(self._opid) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print)    
            # 3460                                         
            
            return (self._ignore_epipe, self._maxsize, self._reader, self._writer,
                    self._rlock, self._wlock, self._sem, self._opid)        
    #</methodize4xi>
            
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "setstate-of-Queue4Xi" usage = "
    #     pool.py
    #         Queue.__setstate__(self, state[:-2])">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/> 
    # ---------------------------------------------------------------------------------------------  
    def __setstate__(self, state):
        '''
        sets queueu state
        '''    

        
        # -----------------------------------------------------------------------------------------    
        # 
        # -----------------------------------------------------------------------------------------          
        class2print = "Queue4Xi"
        method2print = "__setstate__"
        
        message2print = "{started" + "; setstate-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        # 
        
        message2print = "{passed" + "; state-passed-to-setstate-of-Queue4Xi: " + str(state) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
        
     
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------                 
        if examine4xi(class2print, method2print):
        
            # -------------------------------------------------------------------------------------    
            # StepOriginal
            # -------------------------------------------------------------------------------------             
            message2print = "{(StepOriginal) passing" + "; state-passing-to-Queue-setstate-by-setstate-of-Queue4Xi: " + str(state) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
                
                
            Queue.__setstate__(self, state)
                        
        else:
            # -----------------------------------------------------------------------------------------    
            # (Step 1/2)
            # -----------------------------------------------------------------------------------------           
            (self._ignore_epipe, self._maxsize, self._reader, self._writer,
             self._rlock, self._wlock, self._sem, self._opid) = state
            
            message2print = "{(Step 1/2a) set" + "; ignore-epipe-of-queue2xi-set-by-setstate-of-Queue4Xi to: " + str(self._ignore_epipe)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)      
              
            message2print = "{(Step 1/2b) set" + "; maxsize-of-queue2xi-set-by-setstate-of-Queue4Xi to: " + str(self._maxsize)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            
            message2print = "{(Step 1/2c) set" + "; reader-of-queue2xi-set-by-setstate-of-Queue4Xi to: " + str(self._reader)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            
            message2print = "{(Step 1/2d) set" + "; writer-of-queue2xi-set-by-setstate-of-Queue4Xi to: " + str(self._writer)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            
            message2print = "{(Step 1/2e) set" + "; rlock-of-queue2xi-set-by-setstate-of-Queue4Xi to: " + str(self._rlock)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            
            message2print = "{(Step 1/2f) set" + "; wlock-of-queue2xi-set-by-setstate-of-Queue4Xi to: " + str(self._wlock)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            
            message2print = "{(Step 1/2g) set" + "; sem-of-queue2xi-set-by-setstate-of-Queue4Xi to: " + str(self._sem)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
                                      
            
            message2print = "{(Step 1/2h) set" + "; opid-of-queue2xi-set-by-setstate-of-Queue4Xi to: " + str(self._opid)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
                                        
            
            # -----------------------------------------------------------------------------------------    
            # (Step 2/2)
            # -----------------------------------------------------------------------------------------                 
            
            try:
                self._after_fork()      
    
                message2print = "{(Step 2/2a) performed" + "; after-fork--of-queue2xi-performed-by-setstate-of-Queue4Xi: " + str(self._after_fork) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)             
            except:
                message2print = "{(Step 2/2b) yielded" + "; after-fork--of-queue2xi-by-setstate-of-Queue4Xi: " + str(self._after_fork)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print) 
                
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------               
                
        return
                                                     
    #</methodize4xi>
            
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "after-fork-of-Queue4Xi" usage = "
    #   __init__
    #">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/> 
    # ---------------------------------------------------------------------------------------------  
    def _after_fork(self):
        '''
        operations after forking
        '''
        
        # -----------------------------------------------------------------------------------------    
        # 
        # -----------------------------------------------------------------------------------------          
        class2print = "Queue4Xi"
        method2print = "_after_fork"
        
        message2print = "{started" + "; after-fork-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        # 05:46:47 01/22/13 Pacific Standard Time
          
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------                 
        if examine4xi(class2print, method2print):
        
            # -------------------------------------------------------------------------------------    
            # StepOriginal
            # -------------------------------------------------------------------------------------             
            message2print = "{(StepOriginal) calling" + "; Queue-after-fork-calling-by-after-fork-of-Queue4Xi: " + str(Queue._after_fork) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)       
                
                
            Queue._after_fork(self)
        
        else:
            # -----------------------------------------------------------------------------------------    
            # (Step 1/11) - OK
            # -----------------------------------------------------------------------------------------                        
            self._notempty = threading.Condition(threading.Lock())

            message2print = "{(Step 1/11) set" + "; notempty-of-queue2xi-set-by-after-fork-of-Queue4Xi to: " + str(self._notempty)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # <Condition(<_thread.lock object at 0x000000000385D3A0>, 0)>         
                            
            
            # -----------------------------------------------------------------------------------------    
            # (Step 2/11) - OK
            # -----------------------------------------------------------------------------------------                 
            
            self._buffer = collections.deque()

            message2print = "{(Step 2/11) set" + "; buffer-of-queue2xi-set-by-after-fork-of-Queue4Xi to: " + str(self._buffer)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # deque([])           
                            
        
            # -----------------------------------------------------------------------------------------    
            # (Step 3/11) - OK
            # -----------------------------------------------------------------------------------------                 
            
            self._thread = None

            message2print = "{(Step 3/11) set" + "; thread-of-queue2xi-set-by-after-fork-of-Queue4Xi to: " + str(self._thread)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # None                
                            
            
         
            # -----------------------------------------------------------------------------------------    
            # (Step 4/11) - OK
            # -----------------------------------------------------------------------------------------                 
            self._jointhread = None

            message2print = "{(Step 4/11) set" + "; jointhread-of-queue2xi-set-by-after-fork-of-Queue4Xi to: " + str(self._jointhread)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # None          
                            
            # -----------------------------------------------------------------------------------------    
            # (Step 5/11) - OK
            # -----------------------------------------------------------------------------------------                 
            
            self._joincancelled = False

            message2print = "{Step 5/11) set" + "; joincancelled-of-queue2xi-set-by-after-fork-of-Queue4Xi to: " + str(self._joincancelled)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # False          
                            
        
            # -----------------------------------------------------------------------------------------    
            # (Step 6/11) - OK
            # -----------------------------------------------------------------------------------------                 
            
            self._closed = False
            
            message2print = "{(Step 6/11) set" + "; closed-of-queue2xi-set-by-after-fork-of-Queue4Xi to: " + str(self._closed)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # False
            
            
            # -----------------------------------------------------------------------------------------    
            # (Step 7/11) - OK
            # -----------------------------------------------------------------------------------------                 
            
            self._close = None
            
            message2print = "{(Step 7/11) set" + "; close-of-queue2xi-set-by-after-fork-of-Queue4Xi to: " + str(self._close)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # None
            
            
            # -----------------------------------------------------------------------------------------    
            # (Step 8/11) - OK
            # -----------------------------------------------------------------------------------------                 
            
            self._send = self._writer.send
            
            message2print = "{(Step 8/11) set" + "; send-of-queue2xi-set-by-after-fork-of-Queue4Xi to: " + str(self._send)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # <bound method PipeConnection4Xi.send of <pipeconnection4xi.PipeConnection4Xi object at 0x00000000037B1630>>
            
            # -----------------------------------------------------------------------------------------    
            # (Step 9/11) - OK
            # -----------------------------------------------------------------------------------------                 
            
            self._recv = self._reader.recv

            message2print = "{(Step 9/11) set" + "; recv-of-queue2xi-set-by-after-fork-of-Queue4Xi to: " + str(self._recv)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # <bound method PipeConnection4Xi.recv of <pipeconnection4xi.PipeConnection4Xi object at 0x00000000037B1518>>
            
            
            # -----------------------------------------------------------------------------------------    
            # (Step 10/11) - OK
            # -----------------------------------------------------------------------------------------                 
            
            self._poll = self._reader.poll

            message2print = "{(Step 10/11) set" + "; poll-of-queue2xi-set-by-after-fork-of-Queue4Xi to: " + str(self._poll)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # <bound method PipeConnection4Xi.poll of <pipeconnection4xi.PipeConnection4Xi object at 0x00000000037B1518>>
              
            # -----------------------------------------------------------------------------------------    
            # (Step 11/11) - OK
            # -----------------------------------------------------------------------------------------                 
            message2print = "{(Step 11/11) returning" + "; after-fork-of-Queue4Xi-returning: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print) 
            # 05:46:47 01/22/13 Pacific Standard Time
                
                
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------               
                
        return
                         
    #</methodize4xi>
      
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "put-of-Queue4Xi" usage = "
    #   pool.py:
    #       put = outqueue.put
    #   
    #">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------  
    def put(self, obj, block=True, timeout=None):
        '''
        puts to queue
        '''
        
        # -----------------------------------------------------------------------------------------    
        # OK
        # -----------------------------------------------------------------------------------------
        class2print = "Queue4Xi"
        method2print = "put"
        
        message2print = "{started" + "; put-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        # 05:46:47 01/22/13 Pacific Standard Time
        # 05:54:02 02/04/13 Pacific Standard Time
        
        message2print = "{passed" + "; object-passed-to-put-of-Queue4Xi: " + str(obj) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        # ..//..//..//..//web//images//png//2.png
        # {1: '-10x-10y-12z', 2: '-10x-11y-13z', 3: '-10x-3y-27z', 4: '-10x-58y-6z' ...
        
        message2print = "{passed" + "; block-passed-to-put-of-Queue4Xi: " + str(block) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        # True
        
        timeout = omega2timeout4xi(class2print, method2print) 

        message2print = "{set" + "; timeout-set-by-put-of-Queue4Xi to: " + str(timeout)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)      
        # 0.4
           
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------                 
        if examine4xi(class2print, method2print):
        
            # -------------------------------------------------------------------------------------    
            # StepOriginal
            # -------------------------------------------------------------------------------------             
            message2print = "{(StepOriginal) calling" + "; Queue-put-calling-by-put-of-Queue4Xi: " + str(Queue.put) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)       

            Queue.put(self, obj, block, timeout)
            
        else:
                    
            # -----------------------------------------------------------------------------------------    
            # (Step 1/8) - OK
            # -----------------------------------------------------------------------------------------                 
            assert not self._closed
            
            message2print = "{(Step 1/8) asserted" + "; closed-of-queue2xi-asserted-by-put-of-Queue4Xi: " + str(self._closed) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)             
            # False
                              
             
            # -----------------------------------------------------------------------------------------    
            # (Step 2/8) - OK
            # -----------------------------------------------------------------------------------------                 
            message2print = "{(Step 2/8a) passing" + "; block-passing-to-sem-acquire-of-queue2xi-by-put-of-Queue4Xi: " + str(block) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # True
                                     
            message2print = "{(Step 2/8b) passing" + "; timeout-passing-to-sem-acquire-of-queue2xi-by-put-of-Queue4Xi: " + str(timeout) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # 0.4
            
            message2print = "{(Step 2/8c) calling" + "; sem-acquire-calling-by-put-of-Queue4Xi: " + str(self._sem.acquire) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)       
            # <built-in method acquire of _multiprocessing.SemLock object at 0x000000000384E198>
                                                      
            ack2free = False
            nack2free = True
            
            if not self._sem.acquire(block, timeout):
                # -------------------------------------------------------------------------------------    
                # 
                # -------------------------------------------------------------------------------------             
                message2print = "{(Step 2/8d) yielded" + "; nack2free-yielded-by-put-of-Queue4Xi: " + str(nack2freel)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print) 
            else:
                nack2free = False
                ack2free = True           
                
                message2print = "{(Step 2/8e) acknowledged" + "; ack2free-acknowledged-by-put-of-Queue4Xi: " + str(ack2free) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)
                # True; True; time: 05:54:02 02/04/13 Pacific Standard Time
                
            # -----------------------------------------------------------------------------------------    
            # (Step 3/8) - OK
            # -----------------------------------------------------------------------------------------                 
    
            self._notempty.acquire()
    
            message2print = "{(Step 3/8) performed" + "; notempty-acquire-of-queue2xi-performed-by-put-of-Queue4Xi: " + str(self._notempty.acquire) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)             
            # <built-in method acquire of _thread.lock object at 0x00000000039DF170>
            # <built-in method acquire of _thread.lock object at 0x0000000004E140A8>; time: 05:54:02 02/04/13 Pacific Standard Time                                            
            
            # -----------------------------------------------------------------------------------------    
            # (Step 4/8) - OK
            # -----------------------------------------------------------------------------------------                 
            
            message2print = "{(Step 4/8a) trying" + "; thread-of-queue2xi-trying-by-put-of-Queue4Xi: " + str(self._thread)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            # None         
            # <Thread(Queue4XiFeederThread, started daemon 3184)>; time: 05:54:02 02/04/13 Pacific Standard Time
                                     
            try:
                if self._thread is None:
                    # -----------------------------------------------------------------------------    
                    # OK
                    # ----------------------------------------------------------------------------- 
                
                    self._start_thread()
                    
      
                    message2print = "{(Step 4/8b) performed" + "; start-thread-of-queue2xi-performed-by-put-of-Queue4Xi: " + str(self._start_thread) + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)             
                    # <bound method Queue4Xi._start_thread of <queue4xi.Queue4Xi object at 0x000000000386BE10>>              
    
                # -----------------------------------------------------------------------------------------    
                # (Step 5/8) - OK
                # -----------------------------------------------------------------------------------------                 
                message2print = "{(Step 5/8a) passing" + "; object-passing-to-buffer-append-of-queue2xi-by-put-of-Queue4Xi: " + str(obj) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)            
                # ['DragonXi2_00', 'Energy ', 'sensing!']
                # {1: '-10x-10y-12z', 2: '-10x-11y-13z', 3: '-10x-3y-27z', 4: '-10x-58y-6z' ... 
                                                   
                self._buffer.append(obj)
                
                message2print = "{(Step 5/8b) performed" + "; buffer-append-of-queue2xi-performed-by-put-of-Queue4Xi: " + str(self._buffer.append) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)             
                # <built-in method append of collections.deque object at 0x00000000038C8320>;     
                # <built-in method append of collections.deque object at 0x000000000372FD48>; time: 05:54:02 02/04/13 Pacific Standard Time
    
                # -----------------------------------------------------------------------------------------    
                # (Step 6/8) - OK
                # -----------------------------------------------------------------------------------------                 
                  
                self._notempty.notify()
                
                message2print = "{(Step 6/8) performed" + "; notempty-notify-of-queue2xi-performed-by-put-of-Queue4Xi: " + str(self._notempty.notify) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)             
                # <bound method Condition.notify of <Condition(<_thread.lock object at 0x00000000039DF170>, 0)>>;            
                # <bound method Condition.notify of <Condition(<_thread.lock object at 0x0000000004E140A8>, 0)>>; time: 05:54:02 02/04/13 Pacific Standard Time
                
            finally:
                # -----------------------------------------------------------------------------------------    
                # (Step 7/8) - OK
                # -----------------------------------------------------------------------------------------                  
                self._notempty.release()    
    
                message2print = "{(Step 7/8) performed" + "; notempty-release-of-queue2xi-performed-by-put-of-Queue4Xi: " + str(self._notempty.release) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)             
                # <built-in method release of _thread.lock object at 0x00000000039DF170>  
                # <built-in method release of _thread.lock object at 0x0000000004E140A8>; time: 05:54:02 02/04/13 Pacific Standard Time}

            
            # -----------------------------------------------------------------------------------------    
            # (Step 8/8) - OK
            # -----------------------------------------------------------------------------------------                 
            message2print = "{(Step 8/8) returning" + "; put-of-Queue4Xi-returning: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print) 
            # 00:46:47 01/09/13 Pacific Standard Time             
            # 05:54:02 02/04/13 Pacific Standard Time         
                
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------               
                
        return
                       
    #</methodize4xi>
                            
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-of-Queue4Xi" usage = "
    #   pool.py:
    #          get = inqueue.get
    #">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/> 
    # ---------------------------------------------------------------------------------------------   
    def get(self, block=True, timeout=None): # both parameters are optional, timeout being RISKY !
        '''
        Queue4Xi method gets from queue 
        '''
        
        # -----------------------------------------------------------------------------------------    
        # (Step 0/14)
        # -----------------------------------------------------------------------------------------                  
          
        class2print = "Queue4Xi"
        method2print = "get"
        
        message2print = "{(Step 0/14a) started" + "; get-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        # 05:46:47 01/22/13 Pacific Standard Time
        
        message2print = "{(Step 0/14b) passed" + "; block-passed-to-get-of-Queue4Xi: " + str(block) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)          
        # True
        
        message2print = "{(Step 0/14c) passed" + "; timeout-passed-to-get-of-Queue4Xi: " + str(timeout) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
        # None
                 
        # -------------------------------------------------------------------------------------    
        # DRAGONIZED BY TAKING CARE THAT TIMEOUT HAS A VALUE - OTHERWISE SYSTEMS TILT !
        # -------------------------------------------------------------------------------------                 
        timeout = omega2timeout4xi(class2print, method2print) 

        message2print = "{(Step 0/14d) set" + "; timeout-set-by-get-of-Queue4Xi to: " + str(timeout)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)     
        #0.4
     
        # -----------------------------------------------------------------------------------------    
        # (Step 1/14)
        # -----------------------------------------------------------------------------------------                 
        if examine4xi(class2print, method2print):
        
            # -------------------------------------------------------------------------------------    
            # StepOriginal
            # -------------------------------------------------------------------------------------             
            res = Queue.get(self, block, timeout)
         
            message2print = "{(StepOriginal) got" + "; res-got-by-get-orinial-of-Queue4Xi: " + str(res) + "; time: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print) 
            # <copy4xi>copy2one</copy4xi> 
        else:
                       
            # ---------------------------------------------------------------------------------------------    
            # (Step 2/14)
            # ---------------------------------------------------------------------------------------------                 
            res = None          # default is None - hopefully handled by caller ! 
            
            if block and timeout is None:

                # -----------------------------------------------------------------------------------------    
                # START OF CASE BLOCK TRUE AND TIMEOUT IS NONE - *** DO NOT LET IT COME HERE ***
                # -----------------------------------------------------------------------------------------     
                #MATH: this case because it does not give any parameters for get  
                
                try:
                    self._rlock.acquire()
                
                    message2print = "{(Step 2/14a) performed" + "; rlock-acquire-of-queue2xi-performed-by-get-of-Queue4Xi: " + str(self._rlock.acquire) + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)             
                except:
                    message2print = "{(Step 2/14b) yielded" + "; rlock-acquire-of-queue2xi-yielded-by-get-of-Queue4Xi: " + str(self._rlock.acquire)  + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print) 
                                
                   
              
                
                # -----------------------------------------------------------------------------------------    
                # (Step 3/14)
                # -----------------------------------------------------------------------------------------                 
                message2print = "{(Step 3/14a) trying" + "; recv-of-queue2xi-trying-by-get-of-Queue4Xi: " + str(self._recv)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)         
                                   
                
                try:
    
                    # -------------------------------------------------------------------------------------    
                    # Response trial
                    # ------------------------------------------------------------------------------------- 
                
                    try:
    
                        # ---------------------------------------------------------------------------------    
                        # Receive trial
                        # --------------------------------------------------------------------------------- 
                              
                        message2print = "{(Step 3/14a) calling" + "; recv-of-queue2xi-calling-by-get-of-Queue4Xi: " + str(self._recv)  + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print)                                                
                    
                        res = self._recv()
                    
                        message2print = "{(Step 3/14b) got" + "; response-got-by-get-of-Queue4Xi to: " + str(res)  + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print)    
                                        
                                                                 
                    except:
    
                        # ---------------------------------------------------------------------------------    
                        # Exception of Receive
                        # --------------------------------------------------------------------------------- 
                         
                        message2print = "{(Step 3/14c) hit" + "; exception-hit-by-get-of-Queue4Xi: " + " *** recv-of-queue2xi-calling-by-get-of-Queue4Xi failed*** " + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print)
                                        
                        message2print = "{(Step 3/14d) yielded" + "; recv-of-queue2xi-yielded-by-get-of-Queue4Xi: " + str(self._recv)  + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print) 
                                                                          
                    
                    # -------------------------------------------------------------------------------------    
                    # (Step 4/14)
                    # -------------------------------------------------------------------------------------                 
                    message2print = "{(Step 4/14a) trying" + "; sem-release-of-queue2xi-trying-by-get-of-Queue4Xi: " + str(self._sem.release)  + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)
                                      
                                       
                    try:
    
                        # ---------------------------------------------------------------------------------    
                        # Semaphore Release Trial
                        # --------------------------------------------------------------------------------- 
                    
                        self._sem.release()
                    
                        message2print = "{(Step 4/14b) performed" + "; sem-release-of-queue2xi-performed-by-get-of-Queue4Xi: " + str(self._sem.release) + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print)             
                                                 
                    except:
    
                        # ---------------------------------------------------------------------------------    
                        # Exception of Semaphore Release
                        # --------------------------------------------------------------------------------- 
                                  
                        message2print = "{(Step 4/14c) hit" + "; exception-hit-by-get-of-Queue4Xi: " + " *** sem-release-of-queue2xi-failed-by-get-of-Queue4Xi *** " + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print)
                                        
                        message2print = "{(Step 4/14d) yielded" + "; sem-release-of-queue2xi-yielded-by-get-of-Queue4Xi: " + str(self._sem.release)  + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print) 
                                                                     
                    
                    # -------------------------------------------------------------------------------------    
                    # (Step 5/14) - dragonized by having only one return point for res 
                    # -------------------------------------------------------------------------------------                 
                    message2print = "{(Step 5/14a) received" + "; response-received-by-get-of-Queue4Xi: " + str(res) + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)  
                                    


                except:
    
                    # -------------------------------------------------------------------------------------    
                    # Exception of Response
                    # ------------------------------------------------------------------------------------- 
                             
                 
                    message2print = "{(Step 3/14d) hit" + "; exception-hit-by-get-of-Queue4Xi: " + " *** recv-of-queue2xi-failed-by-get-of-Queue4Xi *** " + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)
                                        
                                    
                # -----------------------------------------------------------------------------------------    
                # 
                # -----------------------------------------------------------------------------------------                            
                    
                finally: 
       
                                    
                    # -------------------------------------------------------------------------------------    
                    # (Step 6/14)
                    # -------------------------------------------------------------------------------------                 
                    message2print = "{(Step 6/14a) finalizing" + "; get-finalizing-by-get-of-Queue4Xi: " + str(get) + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)     
                                           
                    try:

                        # ---------------------------------------------------------------------------------    
                        # Semaphore Release Trial
                        # ---------------------------------------------------------------------------------     
                    
                        self._rlock.release()
                    
                        message2print = "{(Step 6/14b) performed" + "; rlock-release-of-queue2xi-performed-by-get-of-Queue4Xi: " + str(self._rlock.release) + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print)             
    
                                                                     
                    except:

                        # ----------------------------------------------------------------------------------    
                        # Exception of Semaphore Release
                        # ----------------------------------------------------------------------------------     
                        message2print = "{(Step 6/14c) yielded" + "; rlock-release-of-queue2xi-yielded-by-get-of-Queue4Xi: " + str(self._rlock.release)  + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print) 
                                  
                    # -------------------------------------------------------------------------------------    
                    #
                    # -------------------------------------------------------------------------------------                 
                    message2print = "{(Step 6/14d) finalized" + "; get-finalized-by-get-of-Queue4Xi: " + str(get) + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)   
                            
                # -----------------------------------------------------------------------------------------    
                # END OF CASE BLOCK TRUE AND TIMEOUT IS NONE
                # -----------------------------------------------------------------------------------------  
                #MATH:
                
            else:
                # -----------------------------------------------------------------------------------------    
                # (Step 7/14) - CASE WHERE EITHER BLOCK ID TRUE TIMEOUT SET BY DRAGON FORCE ! 
                # -----------------------------------------------------------------------------------------                  
            
                if block:
                                  
                    # -------------------------------------------------------------------------------------    
                    # dragonized by taking care that timeout has a value
                    # -------------------------------------------------------------------------------------                 
                    timeout = omega2timeout4xi(class2print, method2print) 

                    message2print = "{(Step 7/14a) set" + "; timeout-set-by-get-of-Queue4Xi to: " + str(timeout)  + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)                         
                    # 0.4
                    
                    deadline = time.time() + timeout
            
                    message2print = "{(Step 7/14b) set" + "; deadline-set-by-get-of-Queue4Xi to: " + str(deadline)  + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)    
                    # 1358862408.116959                 
              
                # -----------------------------------------------------------------------------------------    
                # (Step 8/14) -dragonized by making sure timeout has a value
                # -----------------------------------------------------------------------------------------    
                # CASE WHERE EITHER BLOCK WAS FALSE OR TIMEOUT WAS GIVEN 
                # -----------------------------------------------------------------------------------------     
                timeout = omega2timeout4xi(class2print, method2print) 

                message2print = "{(Step 8/14a) set" + "; timeout-set-by-get-of-Queue4Xi to: " + str(timeout)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)                     
                #0.4
                
                if not self._rlock.acquire(block, timeout):
                                  
                    # -------------------------------------------------------------------------------------    
                    #
                    # -------------------------------------------------------------------------------------                 
                       
                    message2print = "{(Step 8/14b) warned" + "; Empty-possibility-warned-by-get-of-Queue4Xi: " + "** queue might be empty to receive anything **"  + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print) 
                             
                    pass
                    
                
    
                # -----------------------------------------------------------------------------------------    
                # (Step 9/14)
                # -----------------------------------------------------------------------------------------                 
                message2print = "{(Step 9/14a) trying" + "; recv-of-queue2xi-trying-by-get-of-Queue4Xi: " + str(self._recv)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)         
                # <bound method PipeConnection4Xi.recv of <pipeconnection4xi.PipeConnection4Xi object at 0x00000000037B1518>>               
                
                # -----------------------------------------------------------------------------------------    
                # START OF CASE WHERE EITHER BLOCK WAS TRUE OR TIMEOUT FORCED BY DRAGON 
                # -----------------------------------------------------------------------------------------     
                    
                try:
                                  
                    # -------------------------------------------------------------------------------------    
                    # RECEIVING TRIAL
                    # -------------------------------------------------------------------------------------                 
                    pollparameter2xi = (block and (deadline-time.time()) or 0.0 ) * 2 #dragonized
                    
                    message2print = "{(Step 9/14b) calculated" + "; pollparameter2xi-calculated-by-get-of-Queue4Xi: " + str(pollparameter2xi) + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)
                    # 0.7960000038146973
                                    
                    message2print = "{(Step 9/14c) passing" + "; pollparameter2xi-passing-to-poll-of-queue2xi-by-get-of-Queue4Xi: " + str(pollparameter2xi) + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)            
                    # 0.7960000038146973
                    
                    message2print = "{(Step 9/14d) calling" + "; poll-of-queue2xi-calling-by-get-of-Queue4Xi: " + str(self._poll) + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)       
                    # <bound method PipeConnection4Xi.poll of <pipeconnection4xi.PipeConnection4Xi object at 0x00000000037B1518>>
                    
                    # -------------------------------------------------------------------------------------    
                    # RECEIVING TRIAL
                    # -------------------------------------------------------------------------------------                     
                    if not self._poll(pollparameter2xi):
                                  
                        # -------------------------------------------------------------------------------------    
                        # 
                        # ------------------------------------------------------------------------------------- 
                                             
                        message2print = "{(Step 9/14e) warned" + "; Empty-possibility-warned-by-get-of-Queue4Xi: " + "** queue might be empty to receive anything **"  + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print)
                        #MATH: ** queue might be empty to receive anything **
                        
                        pass
                         
                    else:
                        # ----------------------------------------------------------------------------------------------------------------------------    
                        # (Step 10/14) - CONTINUE HERE ONLY IF THERE IS NO POSSIBILITY QUEUE TO BE EMPTY- OTHERWISE RECEIVE WILL KILL THE SYSTEM !!!
                        # ---------------------------------------------------------------------------------------------------------------------------                 
                        message2print = "{(Step 10/14a) calling" + "; recv-of-queue2xi-calling-by-get-of-Queue4Xi: " + str(self._recv) + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print)       
                        # <bound method PipeConnection4Xi.recv of <pipeconnection4xi.PipeConnection4Xi object at 0x0000000003885278>>
                                    
                        try:
                            # ---------------------------------------------------------------------------------     
                            #
                            #----------------------------------------------------------------------------------      
                    
                            res = self._recv()
                    
                            message2print = "{(Step 10/14b) received" + "; response-received-by-get-of-Queue4Xi: " + str(res) + "; time: " + time4xi() + "}"
                            print4xi(class2print, method2print, message2print)
                            # ..//..//..//..//web//images//png//2.png
                        except:
                            # ---------------------------------------------------------------------------------     
                            #
                            #----------------------------------------------------------------------------------      
                    
                            message2print = "{(Step 10/14z) warned" + "; failure-of-receiving-warned-by-get-of-Queue4Xi: " + "** failure-receive by queue2xi  **"  + "; time: " + time4xi() + "}"
                            print4xi(class2print, method2print, message2print)
                             
                                    
                                                         
    
                        # -------------------------------------------------------------------------------------    
                        # (Step 11/14)
                        # -------------------------------------------------------------------------------------                 
                       
                        try:
                            # ---------------------------------------------------------------------------------     
                            #
                            #----------------------------------------------------------------------------------      
                        
                            self._sem.release()
                    
                            message2print = "{(Step 11/14a) released" + "; semaphore-released-by-get-of-Queue4Xi: " + str(self._sem.release) + "; time: " + time4xi() + "}"
                            print4xi(class2print, method2print, message2print)
                            # <built-in method release of _multiprocessing.SemLock object at 0x000000000384E198>  
                        except:
                            # ---------------------------------------------------------------------------------     
                            #
                            #----------------------------------------------------------------------------------     
                        
                            message2print = "{(Step 11/14b) warned" + "; failure-of-semaphore-release-warned-by-get-of-Queue4Xi: " + str(self._sem.release) + "; time: " + time4xi() + "}"
                            print4xi(class2print, method2print, message2print)                           
                                  
                    # -------------------------------------------------------------------------------------    
                    # END OF RECEIVING TRIAL
                    # -------------------------------------------------------------------------------------                 
    
                
                # -----------------------------------------------------------------------------------------    
                # CASE WHERE EITHER BLOCK WAS FALSE OR TIMEOUT WAS GIVEN 
                # -----------------------------------------------------------------------------------------     
                    
                except:
    
                    # -------------------------------------------------------------------------------------    
                    # (Step 12/14)
                    # -------------------------------------------------------------------------------------                 
                               
                    message2print = "{(Step 12/14) hit" + "; exception-hit-by-get-of-Queue4Xi: " + " *** recv-of-queue2xi-calling-by-get-of-Queue4Xi failed*** " + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)
                             
                
                # -----------------------------------------------------------------------------------------    
                # CASE WHERE EITHER BLOCK WAS FALSE OR TIMEOUT WAS GIVEN 
                # -----------------------------------------------------------------------------------------     
                    
                finally:
                
                    # -------------------------------------------------------------------------------------    
                    # (Step 13/14)
                    # -------------------------------------------------------------------------------------                 
  
                    self._rlock.release()
        
                    
                    message2print = "{(Step 13/14) released" + "; recursive-semaphore-released-by-get-of-Queue4Xi: " + str(self._rlock.release) + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)  
                    # <built-in method release of _multiprocessing.SemLock object at 0x0000000003854A30>
                                   
                
                # -----------------------------------------------------------------------------------------    
                # END OF CASE WHERE EITHER BLOCK WAS FALSE OR TIMEOUT WAS GIVEN 
                # -----------------------------------------------------------------------------------------     
              
                


        # -----------------------------------------------------------------------------------------    
        # (Step 14/14)
        # -----------------------------------------------------------------------------------------                 
        if res is None:
                           
            message2print = "{(Step 14/14a) warned" + "; response-warned-by-get-of-Queue4Xi: " + " ** None response returning ** " + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            #MATH: *** comes here ***  
        
        message2print = "{(Step 14/14b) returning" + "; response-returning-by-get-of-Queue4Xi: " + str(res) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
        # ..//..//..//..//web//images//png//2.png
            
        return res            
                
                                
    #</methodize4xi>
            
                
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "qsize-of-Queue4Xi" usage = "
    #     dummy/connection.py:
    #         if self._in.qsize() > 0:
    #">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------  
    def qsize(self):
        '''
        Queue4Xi method qsize returns queue size
        '''
    
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------     
             
        
        class2print = "Queue4Xi"
        method2print = "qsize"
        
        message2print = "{started" + "; qsize-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        # 05:46:47 01/22/13 Pacific Standard Time
        
        # -----------------------------------------------------------------------------------------    
        # (Step 1/1)
        # -----------------------------------------------------------------------------------------                 
        message2print = "{(Step 1/1a) got" + "; maxsize-of-queue2xi-got-by-qsize-of-Queue4Xi: " + str(self._maxsize)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        # 2147483647
                       
        message2print = "{(Step 1/1b) got" + "; value-of-queue2xi-got-by-qsize-of-Queue4Xi: " + str(self._sem._semlock._get_value())  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        # 1
        
        size2xi = self._maxsize - self._sem._semlock._get_value()
        
        message2print = "{(Step 1/1c) calculated" + "; size2xi-calculated-by-qsize-of-Queue4Xi: " + str(size2xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
        # 2147483646
        
        if (size2xi < 0 or size2xi == 0):
            message2print = "{(Step 1/1d) warned" + "; size2xi-warned-by-qsize-of-Queue4Xi: ** challenging queue size: " + str(size2xi)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
            
        message2print = "{(Step 1/1e) returning" + "; size2xi-returning-by-qsize-of-Queue4Xi: " + str(size2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)                                            
        # 2147483646 
        
        return size2xi
        
    #</methodize4xi>
                    
        
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "empty-of-Queue4Xi" usage = "empties queue">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------  
    def empty(self):
        '''
        Queue4Xi method empty: empties queue
        ''' 
    
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------     
                  
        class2print = "Queue4Xi"
        method2print = "empty"
        
        message2print = "{started" + "; empty-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        # 05:46:47 01/22/13 Pacific Standard Time   
        
        # -----------------------------------------------------------------------------------------    
        # (Step 1/1)
        # -----------------------------------------------------------------------------------------                 
        message2print = "{(Step 1/1a) calling" + "; poll-of-queue2xi-calling-by-empty-of-Queue4Xi: " + str(self._poll) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)       
        # <bound method PipeConnection4Xi.poll of <pipeconnection4xi.PipeConnection4Xi object at 0x00000000037B1518>>
                
        message2print = "{(Step 1/1b) returning" + "; poll-function-of-queue2xi-returning-by-empty-of-Queue4Xi: " + str(self._poll) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
        # <bound method PipeConnection4Xi.poll of <pipeconnection4xi.PipeConnection4Xi object at 0x00000000037B1518>>                                     
        
        
        return not self._poll() 
    #</methodize4xi>
            
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "full-of-Queue4Xi" usage = "returns semaphore lock">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------  
    def full(self):
        '''
        Queue4Xi method full: returns whether semaphore lock is zero
        '''
    
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------     
                    
        class2print = "Queue4Xi"
        method2print = "full"
        
        message2print = "{started" + "; full-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        # 05:46:47 01/22/13 Pacific Standard Time
        
        # -----------------------------------------------------------------------------------------    
        # (Step 1/1)
        # -----------------------------------------------------------------------------------------                 
        message2print = "{(Step 1/1) returning" + "; sem-semlock-is-zero-function-of-queue2xi-returning-by-full-of-Queue4Xi: " + str(self._sem._semlock._is_zero) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
        # <built-in method _is_zero of _multiprocessing.SemLock object at 0x0000000003854AD0>
        
        return self._sem._semlock._is_zero()
    #</methodize4xi>
            
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "get-nowait-of-Queue4Xi" usage = "gets with False">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------  
    def get_nowait(self):
        '''
        Queue4Xi method get_nowait: gets with False
        ''' 
    
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------     
              
        class2print = "Queue4Xi"
        method2print = "get_nowait"
        
        message2print = "{started" + "; get-nowait-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        #  
        
        # -----------------------------------------------------------------------------------------    
        # (Step 1/1)
        # -----------------------------------------------------------------------------------------                 
        message2print = "{(Step 1/1) returning" + "; get-function-of-queue2xi-returning-by-get-nowait-of-Queue4Xi: " + str(self.get) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
        #               
             
        return self.get(False)
    #</methodize4xi>
            
            
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "put-nowait-of-Queue4Xi" usage = "puts object without wait">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------  
    def put_nowait(self, obj):
        '''
        Queue4Xi method put_nowait: puts object without wait
        '''
    
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------     
           
        class2print = "Queue4Xi"
        method2print = "put_nowait"
        
        message2print = "{started" + "; put-nowait-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        #    
        message2print = "{passed" + "; object-passed-to-put-nowait-of-Queue4Xi: " + str(obj) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        # 
                        
        # -----------------------------------------------------------------------------------------    
        # (Step 1/1)
        # -----------------------------------------------------------------------------------------                 
        message2print = "{(Step 1/1a) passing" + "; object-passing-to-put-of-queue2xi-by-put-nowait-of-Queue4Xi: " + str(obj) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)            
        #         

        message2print = "{(Step 1/1b) returning" + "; put-function-of-queue2xi-returning-by-put-nowait-of-Queue4Xi: " + str(self.put) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)  
        #                       
        
        return self.put(obj, False)
    #</methodize4xi>
            
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "close-of-Queue4Xi" usage = "closes queue">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------  
    def close(self):
        '''
        Queue4Xi method close: closes queue
        '''
    
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------     
                 
        class2print = "Queue4Xi"
        method2print = "close"
        
        message2print = "{started" + "; close-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
             
        
        # -----------------------------------------------------------------------------------------    
        # (Step 1/1)
        # -----------------------------------------------------------------------------------------                 
        
        self._closed = True
        
        message2print = "{(Step 1/1a) set" + "; closed-of-queue2xi-set-by-close-of-Queue4Xi to: " + str(self._closed)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)    
        #                 
                        
        self._reader.close()
        
        message2print = "{(Step 1/1b) performed" + "; reader-close-of-queue2xi-performed-by-close-of-Queue4Xi: " + str(self._reader.close) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)             
        # 	                
        
        if self._close:
            self._close() 
            
            message2print = "{performed" + "; close-of-queue2xi-performed-by-close-of-Queue4Xi: " + str(self._close) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)             
        else:
        
            pass
                                  
        
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------                 
        message2print = "{returning" + "; close-of-Queue4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print) 
        #                 
                

        return
                          
    #</methodize4xi>
                
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "join-thread-of-Queue4Xi" usage = "joins queue thread">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------  
    def join_thread(self):
        '''
        Queue4Xi method join_thread: joins queue thread
        '''
        
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------                 
          
        class2print = "Queue4Xi"
        method2print = "join_thread"
        
        message2print = "{started" + "; join-thread-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   

             
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------                 
        if examine4xi(class2print, method2print):
        
            # -------------------------------------------------------------------------------------    
            # StepOriginal
            # -------------------------------------------------------------------------------------             
            message2print = "{(StepOriginal) calling" + "; Queue-join-thread-calling-by-join-thread-of-Queue4Xi: " + str(Queue.join_thread) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)       
            #    
                
            Queue.join_thread(self)
        
        else:            
                           
            # -----------------------------------------------------------------------------------------    
            # (Step 1/3)
            # -----------------------------------------------------------------------------------------                 
            if self._closed:
            
                message2print = "{(Step 1/3a) asserted" + "; closed-of-queue2xi-asserted-by-join-thread-of-Queue4Xi: " + str(self._closed) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)         
            else:
                message2print = "{(Step 1/3a) yielded" + "; closed-of-queue2xi-yielded-by-join-thread-of-Queue4Xi: " + str(self._closed)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print) 
                
                    
            # -----------------------------------------------------------------------------------------    
            # (Step 2/3)
            # -----------------------------------------------------------------------------------------                 
            
            if self._jointhread:
            
                try:
                    self._jointhread()
                    
                    message2print = "{(Step 2/3a) performed" + "; jointhread-of-queue2xi-performed-by-join-thread-of-Queue4Xi: " + str(self._jointhread) + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)
                except:
                    message2print = "{(Step 2/3b) yielded" + "; jointhread-of-queue2xi-yielded-by-join-thread-of-Queue4Xi: " + str(self._jointhread)  + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print) 
 
                                                
            else:
                pass
            
                
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------               
          
        message2print = "{(Step 3/3) returning" + "; join-thread-of-Queue4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)                 
        
        return
               
                        
    #</methodize4xi>
                
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "cancel-join-thread-of-Queue4Xi" usage = "cancels join thread">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------  
    def cancel_join_thread(self):
        '''
        Queue4Xi method cancel_join_thread: cancels join thread
        '''
        # -----------------------------------------------------------------------------------------    
        #
        # ----------------------------------------------------------------------------------------- 
        class2print = "Queue4Xi"
        method2print = "cancel_join_thread"
        
        message2print = "{started" + "; cancel-join-thread-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   

      
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------                 
        if examine4xi(class2print, method2print):
        
            # -------------------------------------------------------------------------------------    
            # StepOriginal
            # -------------------------------------------------------------------------------------             
            message2print = "{(StepOriginal) calling" + "; Queue-cancel-join-thread-calling-by-cancel-join-thread-of-Queue4Xi: " + str(Queue.cancel_join_thread) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)       
                
                
            Queue.cancel_join_thread(self)
        else:            
            # -----------------------------------------------------------------------------------------    
            # (Step 1/3)
            # -----------------------------------------------------------------------------------------             
         
            self._joincancelled = True
            
            message2print = "{(Step 1/3) set" + "; joincancelled-of-queue2xi-set-by-cancel-join-thread-of-Queue4Xi to: " + str(self._joincancelled)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
                            
                                   
                     
            # -----------------------------------------------------------------------------------------    
            # (Step 2/3)
            # -----------------------------------------------------------------------------------------                 
            
            try:
                self._jointhread.cancel()
                
                message2print = "{(Step 2/3a) performed" + "; jointhread-cancel-of-queue2xi-performed-by-cancel-join-thread-of-Queue4Xi: " + str(self._jointhread.cancel) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)             
                                   
           
            except:
                message2print = "{yielded" + "; jointhread-cancel-of-queue2xi-yielded-by-cancel-join-thread-of-Queue4Xi: " + str(self._jointhread.cancel)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print) 
                               
                                
            
                pass
                
            # -----------------------------------------------------------------------------------------    
            # 
            # -----------------------------------------------------------------------------------------                 

                
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------               
        message2print = "{(Step 3/3) returning" + "; cancel-join-thread-of-Queue4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)                 
        
        return
                                     
    #</methodize4xi>
            
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "start-thread-of-Queue4Xi" usage = "starts thread which transfers data from buffer to pipe">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/> 
    # ---------------------------------------------------------------------------------------------  
    def _start_thread(self):
        '''
        Queue4Xi method _start_thread: starts thread which transfers data from buffer to pipe
        '''

        # -----------------------------------------------------------------------------------------    
        # (Step 1/9) - OK
        # -----------------------------------------------------------------------------------------                 
        class2print = "Queue4Xi"
        method2print = "_start_thread"
        
        message2print = "{(Step 1/9a) started" + "; start-thread-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        # 05:46:47 01/22/13 Pacific Standard Time
        
        if examine4xi(class2print, method2print):
        
            # -------------------------------------------------------------------------------------    
            # StepOriginal
            # -------------------------------------------------------------------------------------             
            message2print = "{(StepOriginal) calling" + "; Queue-start-thread-calling-by-start-thread-of-Queue4Xi: " + str(Queue._start_thread) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)       
            #     
                  
            Queue._start_thread(self)
        else:
    
            # -----------------------------------------------------------------------------------------    
            # (Step 2/9) - OK
            # -----------------------------------------------------------------------------------------                 
            
    
            self._buffer.clear()
            
            message2print = "{(Step 2/9) performed" + "; buffer-clear-of-queue2xi-performed-by-start-thread-of-Queue4Xi: " + str(self._buffer.clear) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)             
            # <built-in method clear of collections.deque object at 0x00000000038C8320>             
            
            # -----------------------------------------------------------------------------------------    
            # (Step 3/9) - OK
            # -----------------------------------------------------------------------------------------                 
            message2print = "{(Step 3/9a) calling" + "; Thread-calling-by-start-thread-of-Queue4Xi: " + str(threading.Thread) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)       
            # <class 'threading.Thread'>
                            
            message2print = "{(Step 3/9b) passing" + "; Queue4Xi-feed-passing-to-Thread-by-start-thread-of-Queue4Xi: " + str(Queue4Xi._feed) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # <function Queue4Xi._feed at 0x0000000003881488>
                            
            message2print = "{(Step 3/9c) passing" + "; buffer-of-queue2xi-passing-to-Thread-by-start-thread-of-Queue4Xi: " + str(self._buffer) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # deque([])
                             
            message2print = "{(Step 3/9d) passing" + "; notempty-of-queue2xi-passing-to-Thread-by-start-thread-of-Queue4Xi: " + str(self._notempty) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # <Condition(<_thread.lock object at 0x00000000039DF170>
                            
            message2print = "{(Step 3/9e) passing" + "; send-of-queue2xi-passing-to-Thread-by-start-thread-of-Queue4Xi: " + str(self._send) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # <bound method PipeConnection4Xi.send of <pipeconnection4xi.PipeConnection4Xi object at 0x00000000038AFCC0>>              
            
            message2print = "{(Step 3/9f) passing" + "; wlock-of-queue2xi-passing-to-Thread-by-start-thread-of-Queue4Xi: " + str(self._wlock) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # None                          
                            
            message2print = "{(Step 3/9g) passing" + "; writer-close-of-queue2xi-passing-to-Thread-by-start-thread-of-Queue4Xi: " + str(self._writer.close) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # <bound method PipeConnection4Xi.close of <pipeconnection4xi.PipeConnection4Xi object at 0x00000000038AFCC0>>                                   
             
            message2print = "{(Step 3/9h) passing" + "; ignore-epipe-close-of-queue2xi-passing-to-Thread-by-start-thread-of-Queue4Xi: " + str(self._ignore_epipe) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # False
                           
            message2print = "{(Step 3/9i) passing" + "; Queue4XiFeederThread-passing-to-Thread-by-start-thread-of-Queue4Xi: " + str('Queue4XiFeederThread') + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # Queue4XiFeederThread
                       
            self._thread = threading.Thread(
                               target=Queue4Xi._feed,
                               args=(self._buffer, self._notempty, self._send,
                                     self._wlock, self._writer.close, self._ignore_epipe),
            name='Queue4XiFeederThread'
            )

            message2print = "{(Step 3/9j) set" + "; thread-of-queue2xi-set-by-start-thread-of-Queue4Xi to: " + str(self._thread)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # <Thread(Queue4XiFeederThread, initial)>          
                            
            
                    
            # -----------------------------------------------------------------------------------------    
            # (Step 4/9) - OK  
            # -----------------------------------------------------------------------------------------                 
                
            self._thread.daemon = True
            
            message2print = "{(Step 4/9) set" + "; thread-daemon-of-queue2xi-set-by-start-thread-of-Queue4Xi to: " + str(self._thread.daemon)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # True             
                                 
            
            # -----------------------------------------------------------------------------------------    
            # (Step 5/9) - OK
            # -----------------------------------------------------------------------------------------                 
      
            
            self._thread.start()
            
            message2print = "{(Step 5/9) performed" + "; thread-start-of-queue2xi-performed-by-start-thread-of-Queue4Xi: " + str(self._thread.start) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)             
            # <bound method Thread.start of <Thread(Queue4XiFeederThread, started daemon 2980)>>          
            
            
            # -----------------------------------------------------------------------------------------    
            # (Step 6/9) - OK
            # -----------------------------------------------------------------------------------------                 
            
                    
            created_by_this_process = (self._opid == os.getpid())
            
            message2print = "{(Step 6/9a) analyzed" + "; opid-of-queue2xi-analyzed-by-start-thread-of-Queue4Xi: " + str(self._opid) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            # 3460
            
            message2print = "{(Step 6/9b) analyzed" + "; os-pid-analyzed-by-start-thread-of-Queue4Xi: " + str(os.getpid()) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)
            # 3460
            
            message2print = "{(Step 6/9c) set" + "; created-by-this-process-set-by-start-thread-of-Queue4Xi to: " + str(created_by_this_process)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # True             
                                               
                    
            # -----------------------------------------------------------------------------------------    
            # (Step 7/9) - propably OK because passed
            # -----------------------------------------------------------------------------------------                 
            
            if not self._joincancelled and not created_by_this_process:
                message2print = "{(Step 7/9a) informing" + "; process-exit-informing-by-start-thread-of-Queue4Xi: " + "On process exit we will wait for data to be flushed to pipe." + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)    
        
                message2print = "{(Step 7/9b) informing" + "; process-exit-informing-by-start-thread-of-Queue4Xi: " + "However, if this process created the queue then all processes which use the queue will be descendants of this process" + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)   
        
                message2print = "{(Step 7/9c) informing" + "; process-exit-informing-by-start-thread-of-Queue4Xi: " + "Therefore waiting for the queue to be flushed is pointless once all the child processes have been joined." + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)   
              
                message2print = "{(Step 7/9d) calling" + "; Finalize4Xi-calling-by-start-thread-of-Queue4Xi: " + str(Finalize4Xi) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)       
                
                message2print = "{(Step 7/9e) passing" + "; thread-of-queue2xi-passing-to-Finalize4Xi-by-start-thread-of-Queue4Xi: " + str(self._thread) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)            
                                
                
                message2print = "{(Step 7/9f) passing" + "; Queue4Xi-finalize-join-passing-to-Finalize4Xi-by-start-thread-of-Queue4Xi: " + str(Queue4Xi._finalize_join) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)            
                
                message2print = "{(Step 7/9g) passing" + "; weakref-ref-thread-of-queue2xi-passing-to-Finalize4Xi-by-start-thread-of-Queue4Xi: " + str([weakref.ref(self._thread)]) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)            
                
                message2print = "{(Step 7/9h) passing" + "; minus-5-passing-to-Finalize4Xi-by-start-thread-of-Queue4Xi: " + str(-5) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)            
                                            
                                
                self._jointhread = Finalize4Xi(
                    self._thread, Queue4Xi._finalize_join,
                    [weakref.ref(self._thread)],
                    exitpriority=-5
                    )
    
                message2print = "{(Step 7/9i) set" + "; jointhread-of-queue2xi-set-by-start-thread-of-Queue4Xi to: " + str(self._jointhread)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)    
                                
                                                   
            
            # -----------------------------------------------------------------------------------------    
            # (Step 8/9) - OK
            # -----------------------------------------------------------------------------------------                 
            message2print = "{(Step 8/9a) informing" + "; sentinel-sending-informing-by-start-thread-of-Queue4Xi: Sending sentinel to the thread queue object when garbage collected ; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)                      
            # Sending sentinel to the thread queue object when garbage collected
            
            message2print = "{(Step 8/9b) passing" + "; queue2xi-passing-to-Finalize4Xi-by-start-thread-of-Queue4Xi: " + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # self no traced because it is risky
            
            message2print = "{(Step 8/9c) passing" + "; Queue4Xi-finalize-close-passing-to-Finalize4Xi-by-start-thread-of-Queue4Xi: " + str(Queue4Xi._finalize_close) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # <function Queue4Xi._finalize_close at 0x0000000003881400>
            
            message2print = "{(Step 8/9d) passing" + "; buffer-notempty-elelement-of-queue2xi-passing-to-Finalize4Xi-by-start-thread-of-Queue4Xi: " + str([self._buffer, self._notempty]) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # [deque([])
            

            message2print = "{(Step 8/9e) passing" + "; 10-passing-to-Finalize4Xi-by-start-thread-of-Queue4Xi: " + str(10) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # 10;               
                            

            self._close = Finalize4Xi(
                self, Queue4Xi._finalize_close,
                [self._buffer, self._notempty],
                exitpriority=10
                )    
                
            message2print = "{(Step 8/9e) performed" + "; close-of-queue2xi-performed-by-start-thread-of-Queue4Xi: " + str(self._close) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)             
            # <finalize4xi: __repr__: Finalize object, callback=_finalize_close, args=[deque([])
                            
                
            # -----------------------------------------------------------------------------------------    
            # (Step 9/9) - OK
            # -----------------------------------------------------------------------------------------                 
            message2print = "{(Step 9/9) returning" + "; start-thread-of-Queue4Xi-returning: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print) 
            # 05:46:47 01/22/13 Pacific Standard Time                        
           
                
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------               
                
        return
                 
                        
    #</methodize4xi>
                
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "finalize-join-of-Queue4Xi" usage = "finalizes queue join thread">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------  
    @staticmethod
    def _finalize_join(twr):
        '''
        Queue4Xi method _finalize_join: finalizes queue join thread 
        '''
        
         
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------                 
        class2print = "Queue4Xi"
        method2print = "_finalize_join"
        
        message2print = "{started" + "; finalize-join-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        
        message2print = "{passed" + "; twr-passed-to-finalize-join-of-Queue4Xi: " + str(twr) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)              
                         
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------                 
        if examine4xi(class2print, method2print):
        
            # -------------------------------------------------------------------------------------    
            # StepOriginal
            # -------------------------------------------------------------------------------------             
            message2print = "{(StepOriginal) calling" + "; Queue-finalize-join-calling-by-finalize-join-of-Queue4Xi: " + str(Queue._finalize_join) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)       
 
            Queue._finalize_join(twr)
        else:
                      
            # -----------------------------------------------------------------------------------------    
            # (Step 1/3) 
            # -----------------------------------------------------------------------------------------          

            try:
                thread = twr()
         
                message2print = "{(Step 1/3a) set" + "; thread-set-by-finalize-join-of-Queue4Xi to: " + str(thread)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)    
            except:
                             
                message2print = "{(Step 1/3b) hit" + "; twr-hit-by-finalize-join-of-Queue4Xi: " + " *** " + str(twr)  + " *** " + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)
                    
                                            
                   
            # -----------------------------------------------------------------------------------------    
            #
            # -----------------------------------------------------------------------------------------                 
            
            if thread is not None:
                # -------------------------------------------------------------------------------------    
                # (Step 2/3) 
                # -------------------------------------------------------------------------------------                 
                 
                try:
                    thread.join()
                    
                    message2print = "{(Step 2/3a) performed" + "; thread-join-performed-by-finalize-join-of-Queue4Xi: " + str(thread.join) + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)             
                except:
                    message2print = "{(Step 2/3b) yielded" + "; thread-join-yielded-by-finalize-join-of-Queue4Xi: " + str(thread.join)  + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print) 
                                            
                
            else:
                message2print = "{(Step 2/3c) yielded" + "; thread-yielded-by-finalize-join-of-Queue4Xi: queue thread already dead ; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)                         
                
            # -----------------------------------------------------------------------------------------    
            #
            # -----------------------------------------------------------------------------------------                 

                        
                
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------               
        message2print = "{(Step 3/3) returning" + "; finalize-join-of-Queue4Xi-returning: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)                 
        
        return
              
                             
    #</methodize4xi>
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "finalize-close-of-Queue4Xi" usage = "finalizes queue closing">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------  
    @staticmethod
    def _finalize_close(buffer, notempty):
        '''
        Queue4Xi method _finalize_close: finalizes queue closing
        '''

        # -----------------------------------------------------------------------------------------    
        # (Step 0/6) - OK 
        # -----------------------------------------------------------------------------------------        
        
        class2print = "Queue4Xi"
        method2print = "_finalize_close"
        
        message2print = "{(Step 0/6a) started" + "; finalize-close-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        # 00:46:51 01/09/13 Pacific Standard Time
           
        message2print = "{(Step 0/6b) passed" + "; buffer-passed-to-finalize-close-of-Queue4Xi: " + str(buffer) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        # deque([])
            
        message2print = "{(Step 0/6c) passed" + "; notempty-passed-to-finalize-close-of-Queue4Xi: " + str(notempty) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)  
        # <Condition(<_thread.lock object at 0x0000000003B2C1C0>, 1)>   
                
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------                 
        if examine4xi(class2print, method2print):
        
            # -------------------------------------------------------------------------------------    
            # StepOriginal
            # -------------------------------------------------------------------------------------             
            message2print = "{(StepOriginal) calling" + "; Queue-finalize-close-calling-by-finalize-close-of-Queue4Xi: " + str(Queue._finalize_close) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)       
                            
                                  
            Queue._finalize_close(buffer, notempty)
        else:
            # -----------------------------------------------------------------------------------------    
            # (Step 1/6) - OK 
            # -----------------------------------------------------------------------------------------                 

            message2print = "{(Step 1/6) informing" + "; quit-informing-by-finalize-close-of-Queue4Xi: telling queue thread to quit; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)              
            # 00:46:51 01/09/13 Pacific Standard Time
            
            # -----------------------------------------------------------------------------------------    
            # (Step 2/6) - OK 
            # -----------------------------------------------------------------------------------------                 
            
            notempty.acquire()
    
            message2print = "{(Step 2/6a) performed" + "; notempty.acquire-performed-by-finalize-close-of-Queue4Xi: " + str(notempty.acquire) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)             
            # <built-in method acquire of _thread.lock object at 0x0000000003B2C1C0>            
                    
              
            message2print = "{(Step 2/6b) passing" + "; sentinel-passing-to-buffer-append-by-finalize-close-of-Queue4Xi: " + str(_sentinel) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # <object object at 0x000000000242D420>         
                            
                    
            try:
                

                # -------------------------------------------------------------------------------------    
                # (Step 3/6) - OK 
                # -------------------------------------------------------------------------------------                 
            
                buffer.append(_sentinel)
    
                message2print = "{(Step 3/6) appended" + "; sentinel-appended-by-finalize-close-of-Queue4Xi: " + str(_sentinel) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)                  
                # <object object at 0x000000000242D420>
                
                # -------------------------------------------------------------------------------------    
                # (Step 4/6) - OK 
                # -------------------------------------------------------------------------------------                 
                
                notempty.notify()
    
                message2print = "{(Step 4/6) performed" + "; notempty-notify-performed-by-finalize-close-of-Queue4Xi: " + str(notempty.notify) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)             
                # <bound method Condition.notify of <Condition(<_thread.lock object at 0x0000000003B2C1C0>, 0)>>                          
                            
                
            finally:

                # -------------------------------------------------------------------------------------    
                # (Step 5/6) - OK 
                # -------------------------------------------------------------------------------------                 
                
                notempty.release()
                
                message2print = "{(Step 5/6) performed" + "; notempty.release-performed-by-finalize-close-of-Queue4Xi: " + str(notempty.release) + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)             
                # <built-in method release of _thread.lock object at 0x0000000003B2C1C0>                       
             
            
            # -----------------------------------------------------------------------------------------    
            # (Step 6/6) - OK 
            # -----------------------------------------------------------------------------------------                 
            message2print = "{(Step 6/6) returning" + "; finalize-close-of-Queue4Xi-returning: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print) 
            # 00:46:51 01/09/13 Pacific Standard Time                    
                            
                
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------               
                
        return
         
                                        
    #</methodize4xi>
               
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "feed-of-Queue4Xi" usage = "provides queue feed">
    #<state4xi status = "ACK4review; ACK4tagging; ACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------  
    @staticmethod
    def _feed(buffer, notempty, send, writelock, close, ignore_epipe):
        '''
        Queue4Xi method _feed: provides queue feed
        '''

        # -----------------------------------------------------------------------------------------    
        # (Step 0/9) - OK
        # -----------------------------------------------------------------------------------------        
        class2print = "Queue4Xi"
        method2print = "_feed"
        
        message2print = "{(Step 0/9a) started" + "; feed-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
        # 00:46:47 01/09/13 Pacific Standard Time
        
        message2print = "{(Step 0/9b) passed" + "; buffer-passed-to-feed-of-Queue4Xi: " + str(buffer) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)               
        # deque([])
                
        message2print = "{(Step 0/9c) passed" + "; notempty-passed-to-feed-of-Queue4Xi: " + str(notempty) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)               
        # <Condition(<_thread.lock object at 0x00000000039DF170>, 0)>
                
        message2print = "{(Step 0/9d) passed" + "; send-passed-to-feed-of-Queue4Xi: " + str(send) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)               
        # <bound method PipeConnection4Xi.send of <pipeconnection4xi.PipeConnection4Xi object at 0x00000000038AFCC0>>
                
        message2print = "{(Step 0/9e) passed" + "; writelock-passed-to-feed-of-Queue4Xi: " + str(writelock) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)               
        # None
                
        message2print = "{(Step 0/9f) passed" + "; close-passed-to-feed-of-Queue4Xi: " + str(close) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)               
        # <bound method PipeConnection4Xi.close of <pipeconnection4xi.PipeConnection4Xi object at 0x00000000038AFCC0>>
         
        message2print = "{(Step 0/9g) passed" + "; ignore-epipe-passed-to-feed-of-Queue4Xi: " + str(ignore_epipe) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)               
        # False
                   
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------                 
        if examine4xi(class2print, method2print):
        
            # -------------------------------------------------------------------------------------    
            # StepOriginal
            # -------------------------------------------------------------------------------------             
            message2print = "{(StepOriginal) calling" + "; Queue-feed-calling-by-feed-of-Queue4Xi: " + str(Queue._feed) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)       
                     
                     
            Queue._feed(buffer, notempty, send, writelock, close, ignore_epipe)
        else:    
            
            # -----------------------------------------------------------------------------------------    
            # (Step 1/9) - OK
            # -----------------------------------------------------------------------------------------                 

            message2print = "{(Step 1/9) informing" + "; feed-informing-by-feed-of-Queue4Xi: starting thread to feed data to pipe; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)                      
            # starting thread to feed data to pipe; time: 00:46:47 01/09/13 Pacific Standard Time
            
            # -----------------------------------------------------------------------------------------    
            # (Step 2/9) - OK
            # -----------------------------------------------------------------------------------------                 
    
            nacquire = notempty.acquire
            
            message2print = "{(Step 2/9) set" + "; nacquire-set-by-feed-of-Queue4Xi to: " + str(nacquire)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # <built-in method acquire of _thread.lock object at 0x00000000039DF170>           
                                     
            
            # -----------------------------------------------------------------------------------------    
            # (Step 3/9) - OK
            # -----------------------------------------------------------------------------------------                 
             
            nrelease = notempty.release
            
            
            message2print = "{(Step 3/9) set" + "; nrelease-set-by-feed-of-Queue4Xi to: " + str(nrelease)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # <built-in method release of _thread.lock object at 0x00000000039DF170>
            
            # -----------------------------------------------------------------------------------------    
            # (Step 4/9) - OK
            # -----------------------------------------------------------------------------------------                 
             
            nwait = notempty.wait
            
            
            message2print = "{(Step 4/9) set" + "; nwait-set-by-feed-of-Queue4Xi to: " + str(nwait)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)    
            # <Condition(<_thread.lock object at 0x00000000039DF170>, 0)>>
            
            # -----------------------------------------------------------------------------------------    
            # (Step 5/9) - OK
            # -----------------------------------------------------------------------------------------                 
             
            bpopleft = buffer.popleft
            
            message2print = "{(Step 5/9) set" + "; bpopleft-set-by-feed-of-Queue4Xi to: " + str(bpopleft)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)            
            # <built-in method popleft of collections.deque object at 0x00000000038C8320>
            
            # -----------------------------------------------------------------------------------------    
            # (Step 6/9) - OK
            # -----------------------------------------------------------------------------------------                 
             
            sentinel = _sentinel
            
            message2print = "{(Step 6/9) set" + "; sentinel-set-by-feed-of-Queue4Xi to: " + str(sentinel)  + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print)           
            # <object object at 0x000000000242D420>
            
            # -----------------------------------------------------------------------------------------    
            # (Step 7/9) - OK
            # -----------------------------------------------------------------------------------------                 
            
            if sys.platform != get_windows_system4xi():
    
                # -----------------------------------------------------------------------------------------    
                #
                # -----------------------------------------------------------------------------------------    
                     
                wacquire = writelock.acquire
                
                message2print = "{(Step 7/9a) set" + "; wacquire-set-by-feed-of-Queue4Xi to: " + str(wacquire)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)    
                                
                                               
                
                # -----------------------------------------------------------------------------------------    
                #
                # -----------------------------------------------------------------------------------------             
            
                wrelease = writelock.release
                
                message2print = "{(Step 7/9b) set" + "; wrelease-set-by-feed-of-Queue4Xi to: " + str(wrelease)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)                    
                        
            
            else:
                
                # -----------------------------------------------------------------------------------------    
                # 
                # -----------------------------------------------------------------------------------------             
            
                wacquire = None
                
                message2print = "{(Step 7/9c) set" + "; wacquire-set-by-feed-of-Queue4Xi to: " + str(wacquire)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)                                
                # None
       
            # -----------------------------------------------------------------------------------------    
            # (Step 8/9) - 
            # -----------------------------------------------------------------------------------------                 
     
            message2print = "{(Step 8/9a) entering" + "; while-loop-entering-by-feed-of-Queue4Xi: " + str(nacquire) + "; time: " + time4xi() + "}"
            print4xi(class2print, method2print, message2print) 
            # <built-in method acquire of _thread.lock object at 0x00000000039DF170>
            
            
            # -----------------------------------------------------------------------------------------    
            #
            # -----------------------------------------------------------------------------------------             
            try:
                # -------------------------------------------------------------------------------------    
                #
                # -------------------------------------------------------------------------------------                 
                message2print = "{(Step 8/9b) trying" + "; nacquire-trying-by-feed-of-Queue4Xi: " + str(nacquire)  + "; time: " + time4xi() + "}"
                print4xi(class2print, method2print, message2print)         
                # <built-in method acquire of _thread.lock object at 0x00000000039DF170>                   
                
                while 1:
                    
                    # ---------------------------------------------------------------------------------    
                    #
                    # ---------------------------------------------------------------------------------                      
                    nacquire()
                    
                    message2print = "{(Step 8/9c) performed" + "; nacquire-performed-by-feed-of-Queue4Xi: " + str(nacquire) + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)             
                    # <built-in method acquire of _thread.lock object at 0x00000000039DF170>               
                    
                    # ---------------------------------------------------------------------------------    
                    #
                    # ---------------------------------------------------------------------------------                          
                    try:
                        if not buffer:
                            message2print = "{(Step 8/9d) calling" + "; nwait-calling-by-feed-of-Queue4Xi: " + str(nwait) + "; time: " + time4xi() + "}"
                            print4xi(class2print, method2print, message2print)       
                
                                        
                            nwait()

                            message2print = "{(Step 8/9e) performed" + "; nwait-performed-by-feed-of-Queue4Xi: " + str(nwait) + "; time: " + time4xi() + "}"
                            print4xi(class2print, method2print, message2print)             
                                                
                    
                    # ---------------------------------------------------------------------------------    
                    # OK
                    # ---------------------------------------------------------------------------------                          
                    finally:
                        nrelease()
                        
                        message2print = "{(Step 8/9f) performed" + "; nrelease-performed-by-feed-of-Queue4Xi: " + str(nrelease) + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print)             
                        # <built-in method release of _thread.lock object at 0x00000000039DF170>                                
                    
                    # ---------------------------------------------------------------------------------    
                    # 
                    # ---------------------------------------------------------------------------------                              
                    message2print = "{(Step 8/9g) trying" + "; bpopleft-trying-by-feed-of-Queue4Xi: " + str(bpopleft)  + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)         
                    # <built-in method popleft of collections.deque object at 0x00000000038C8320>           
                    
                    try:
    
                        # -------------------------------------------------------------------------    
                        # START OF WHILE
                        # ------------------------------------------------------------------------- 
     
            
                        while 1:

                            # ---------------------------------------------------------------------    
                            # NACK: the first one ok, but did NOT handle other indexes TASKS1 = [(mul, (i, 7)) for i in range(20)]
                            #----------------------------------------------------------------------     

                        
                            obj = bpopleft()

                            message2print = "{(Step 8/9h) set" + "; object-set-by-feed-of-Queue4Xi to: " + str(obj)  + "; time: " + time4xi() + "}"
                            print4xi(class2print, method2print, message2print)    
                            # ['DragonXi2_00', 'Energy ', 'sensing!']

                            # ---------------------------------------------------------------------    
                            #
                            #----------------------------------------------------------------------     

                            
                            if obj is sentinel:
 
                                # -----------------------------------------------------------------    
                                #
                                # -----------------------------------------------------------------
                                
                                message2print = "{(Step 8/9i) got" + "; sentinel-got-by-feed-of-Queue4Xi: " + str(sentinel)  + "; time: " + time4xi() + "}"
                                print4xi(class2print, method2print, message2print)
                                # MATH: sentinel-got-by-feed-of-Queue4Xi: object object at 0x02E164B0                
                                
                                close()
                                
                                message2print = "{(Step 8/9j) closed" + "; close-function-by-feed-of-Queue4Xi: " + str(close) + "; time: " + time4xi() + "}"
                                print4xi(class2print, method2print, message2print)                                  
                                
                                message2print = "{(Step 8/9k) returning" + "; feed-of-Queue4Xi-returning: " + time4xi() + "}" 
                                print4xi(class2print, method2print, message2print) 
                                
                                return

                            # ---------------------------------------------------------------------    
                            #
                            #----------------------------------------------------------------------     

    
                            if wacquire is None:

                                # -----------------------------------------------------------------    
                                # OK
                                # -----------------------------------------------------------------
                            
                                message2print = "{(Step 8/9l) passing" + "; object-passing-to-send-by-feed-of-Queue4Xi: " + str(obj) + "; time: " + time4xi() + "}"
                                print4xi(class2print, method2print, message2print)            
                                # ['DragonXi2_00', 'Energy ', 'sensing!'] 
                                # <copy4xi>copy2one</copy4xi>
                                try:                                
                                    send(obj)
                                    
                                    message2print = "{(Step 8/9m) sent" + "; object-sent-by-feed-of-Queue4Xi: " + str(obj)  + "; time: " + time4xi() + "}"
                                    print4xi(class2print, method2print, message2print)
                                    # ['DragonXi2_00', 'Energy ', 'sensing!']
                                    # <copy4xi>copy2one</copy4xi>
                                except:
                                    message2print = "{(Step 8/9z) failed" + "; object-failed-by-feed-of-Queue4Xi: " + str(obj)  + "; time: " + time4xi() + "}"
                                    print4xi(class2print, method2print, message2print)
                                    # <object object at 0x000000000242D430>
                                                                     
                            else:

                                # -----------------------------------------------------------------    
                                #
                                # -----------------------------------------------------------------
                            
                                wacquire()
                                
                                message2print = "{(Step 8/9n) performed" + "; wacquire-performed-by-feed-of-Queue4Xi: " + str(wacquire) + "; time: " + time4xi() + "}"
                                print4xi(class2print, method2print, message2print)             
                                                
                                try:

                                    # -------------------------------------------------------------    
                                    #
                                    # -------------------------------------------------------------  
                                       
                                    message2print = "{(Step 8/9o) passing" + "; object-passing-to-send-by-feed-of-Queue4Xi: " + str(obj) + "; time: " + time4xi() + "}"
                                    print4xi(class2print, method2print, message2print)            

                                    send(obj)
                                finally:

                                    # -------------------------------------------------------------    
                                    #
                                    # -------------------------------------------------------------  
                                       
                                    wrelease()
                                    
                                    message2print = "{(Step 8/9p) performed" + "; wrelease-performed-by-feed-of-Queue4Xi: " + str(wrelease) + "; time: " + time4xi() + "}"
                                    print4xi(class2print, method2print, message2print)             
 
                            # ---------------------------------------------------------------------    
                            #
                            #----------------------------------------------------------------------     

   
                        # -------------------------------------------------------------------------    
                        # END OF WHILE
                        # ------------------------------------------------------------------------- 
                        
                    # ---------------------------------------------------------------------------------    
                    #
                    # ---------------------------------------------------------------------------------                                                     
                    except IndexError:
   
                        # -------------------------------------------------------------------------    
                        # 
                        # ------------------------------------------------------------------------- 
                       
                        message2print = "{(Step 8/9q) warned" + "; possible-IndexError-warned-by-feed-of-Queue4Xi: " + " ** " + str(IndexError)  + " ** " + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print)
                        # 00:46:47 01/09/13 Pacific Standard Time             
                        
                        message2print = "{(Step 8/9r) informing" + "; Ignore-informing-by-feed-of-Queue4Xi: " + "because of running in a daemon the thread,  resources it uses may become unusable while the process is cleaning up! " + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print)                                      
                        # 00:46:47 01/09/13 Pacific Standard Time
                        
                        pass
    
                        # -------------------------------------------------------------------------    
                        #
                        # ------------------------------------------------------------------------- 
            
            # -----------------------------------------------------------------------------------------    
            # (Step 9/9) 
            # -----------------------------------------------------------------------------------------    
                          
            except Exception as e:
                # Since this runs in a daemon thread the resources it uses
                # may be become unusable while the process is cleaning up.
                # We ignore errors which happen after the process has
                # started to cleanup.

                # -------------------------------------------------------------------------------------    
                #
                # -------------------------------------------------------------------------------------                 
                  
                
                try:
                    if is_exiting4xi():
                        # ----------------------------------------------------------------------------    
                        #
                        # ----------------------------------------------------------------------------                 

                        
                        info('error in queue thread: %s', e)
                        
                        message2print = "{(Step 9/9a) hit" + "; exception-hit-by-feed-of-Queue4Xi: " + " * resources daemon thread used unusable while the process is cleaning up - ignore this *  " + str(e)  + " ** " + "; time: " + time4xi() + "}"
                        print4xi(class2print, method2print, message2print)
                                            
                                        
                        
                        # ----------------------------------------------------------------------------    
                        #
                        # ----------------------------------------------------------------------------                 
                                                       
                           
                    else:
                        # ----------------------------------------------------------------------------    
                        #
                        # ----------------------------------------------------------------------------                 
                                                       
                       
                        import traceback
                        traceback.print_exc()
                        
                        
                except Exception:

                    message2print = "{(Step 9/9b) hit" + "; exception-hit-by-feed-of-Queue4Xi: " + " *** is_exiting4xi failed - resources daemon thread used unusable while the process is cleaning up - ignore this *** " + "; time: " + time4xi() + "}"
                    print4xi(class2print, method2print, message2print)
                                        
                                       
            # -----------------------------------------------------------------------------------------    
            #
            # -----------------------------------------------------------------------------------------                 
            message2print = "{returning" + "; feed-of-Queue4Xi-returning: " + time4xi() + "}" 
            print4xi(class2print, method2print, message2print) 
                        
                
        # -----------------------------------------------------------------------------------------    
        #
        # -----------------------------------------------------------------------------------------               
                
        return
              
                        
    #</methodize4xi>
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "sense-of-Queue4Xi" usage = "senses Queue4Xi class objects">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def sense(self):
        '''
        method sense: senses Queue4Xi class objects
        '''
        
        
        class2print = 'Queue4Xi'
        method2print = 'sense'
        
        message2print = "{started" + "; sense-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
                        
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------  
        message2print = "{sensing" + "; Queue4Xi-sensing-by-sense-of-Queue4Xi: " + str(Queue4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                      
        
        # -----------------------------------------------------------------------------------------
        # get sensed knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb2xi = sense_object4xi(self)
        
        message2print = "{got" + "; knowledge-base2xi-got-by-sense-of-Queue4Xi: " + str(kb2xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # -----------------------------------------------------------------------------------------         
        try:
            kb2xi['maxsize-of-queue2xi'] = self._maxsize    
        except:
            pass    
        try:
            kb2xi['reader-of-queue2xi'] = self._reader           
        except:
            pass    
        try:
            kb2xi['writer-of-queue2xi'] = self._writer           
        except:
            pass    
        try:
            kb2xi['rlock-of-queue2xi'] = self._rlock  
        except:
            pass    
        try:
            kb2xi['opid-of-queue2xi'] = self._opid     
        except:
            pass    
        try:
            kb2xi['wlock-of-queue2xi'] = self._wlock           
        except:
            pass    
        try:
            kb2xi['sem-of-queue2xi'] = self._sem           
        except:
            pass    
        try:
            kb2xi['writer-send-of-queue2xi'] = self._writer.send          
        except:
            pass    
        try:
            kb2xi['reader-recv-of-queue2xi'] = self._reader.recv     
        except:
            pass    
        try:
            kb2xi['reader-poll-of-queue2xi'] = self._reader.poll           
        except:
            pass    
        try:
            kb2xi['closed-of-queue2xi'] = self._closed           
        except:
            pass    
        try:
            kb2xi['sem-acquire-of-queue2xi'] = self._sem.acquire  
        except:
            pass    
        try:
            kb2xi['notempty-acquire-of-queue2xi'] = self._notempty.acquire     
        except:
            pass    
        try:
            kb2xi['thread-of-queue2xi'] = self._thread           
        except:
            pass    
        try:
            kb2xi['start-thread-of-queue2xi'] = self._start_thread           
        except:
            pass    
        try:
            kb2xi['buffer-append-of-queue2xi'] = self._buffer.append  
        except:
            pass    
        try:
            kb2xi['notempty-notify-of-queue2xi'] = self._notempty.notify     
        except:
            pass    
        try:
            kb2xi['notempty-release-of-queue2xi'] = self._notempty.release           
        except:
            pass    
        try:
            kb2xi['rlock-acquire-of-queue2xi'] = self._rlock.acquire           
        except:
            pass    
        try:
            kb2xi['recv-of-queue2xi'] = self._recv  
        except:
            pass    
        try:
            kb2xi['sem-release-of-queue2xi'] = self._sem.release     
        except:
            pass    
        try:
            kb2xi['poll-of-queue2xi'] = self._poll            
        except:
            pass    
        try:
            kb2xi['rlock-release-of-queue2xi'] = self._rlock.release           
        except:
            pass    
        try:
            kb2xi['maxsize-of-queue2xi'] = self._maxsize          
        except:
            pass    
        try:
            kb2xi['get-of-queue2xi'] = self.get     
        except:
            pass    
        try:
            kb2xi['put-of-queue2xi'] = self.put           
        except:
            pass    
        try:
            kb2xi['closed-of-queue2xi'] = self._closed           
        except:
            pass    
        try:
            kb2xi['reader-close-of-queue2xi'] = self._reader.close  
        except:
            pass    
        try:
            kb2xi['close-of-queue2xi'] = self._close     
        except:
            pass    
        try:
            kb2xi['jointhread-of-queue2xi'] = self._jointhread           
        except:
            pass    
        try:
            kb2xi['joincancelled-of-queue2xi'] = self._joincancelled           
        except:
            pass    
        try:
            kb2xi['buffer-clear-of-queue2xi'] = self._buffer.clear  
        except:
            pass    
        try:
            kb2xi['thread.daemon-of-queue2xi'] = self._thread.daemon     
        except:
            pass    
        try:
            kb2xi['thread.start-of-queue2xi'] = self._thread.start           
        except:
            pass    
        try:
            kb2xi['opid-of-queue2xi'] = self._opid           
        except:
            pass    
        try:
            kb2xi['joincancelled-of-queue2xi'] = self._joincancelled  
        except:
            pass    
        try:
            kb2xi['jointhread-of-queue2xi'] = self._jointhread     
        except:
            pass    
      
        
                 
        message2print = "{sensed" + "; Queue4Xi-sensed-by-sense-of-Queue4Xi: " + str(Queue4Xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)       
        
        # -----------------------------------------------------------------------------------------
        # 
        # -----------------------------------------------------------------------------------------         
        message2print = "{returning" + "; knowledge-base2xi-returning-by-sense-of-Queue4Xi: " + str(kb2xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
        #test_math4xi.py: SENSED TASK QUEUE AFTER TASKS HAVE BEEN PUT TO QUEUES!")          
        #
        # {            'poll-of-queue2xi': <built-in method poll of _multiprocessing.PipeConnection object at 0x02F73068>, 
        #  'notempty-acquire-of-queue2xi': <built-in method acquire of _thread.lock object at 0x02FA8550>, 
        #      'thread.start-of-queue2xi': <bound method Thread.start of <Thread(Queue4XiFeederThread, started daemon 4492)>>,
        #            'thread-of-queue2xi': <Thread(Queue4XiFeederThread, started daemon 4492)>,
        #       'sem-acquire-of-queue2xi': <built-in method acquire of _multiprocessing.SemLock object at 0x02FF9DC0>,
        #            'reader-of-queue2xi': <read-only PipeConnection, handle 412>, 
        #  'notempty-release-of-queue2xi': <built-in method release of _thread.lock object at 0x02FA8550>,
        #              'recv-of-queue2xi': <built-in method recv of _multiprocessing.PipeConnection object at 0x02F73068>,
        #     'buffer-append-of-queue2xi': <built-in method append of collections.deque object at 0x0302E0A0>,
        #             'wlock-of-queue2xi': None,
        #       'writer-send-of-queue2xi': <built-in method send of _multiprocessing.PipeConnection object at 0x02F734B0>, 
        #       'reader-recv-of-queue2xi': <built-in method recv of _multiprocessing.PipeConnection object at 0x02F73068>,
        #     'joincancelled-of-queue2xi': False,
        #       'reader-poll-of-queue2xi': <built-in method poll of _multiprocessing.PipeConnection object at 0x02F73068>,
        #      'start-thread-of-queue2xi': <bound method Queue4Xi._start_thread of <queue4xi.Queue4Xi object at 0x02FD7370>>,
        #           'maxsize-of-queue2xi': 2147483647,
        #       'sem-release-of-queue2xi': <built-in method release of _multiprocessing.SemLock object at 0x02FF9DC0>,
        #               'sem-of-queue2xi': <BoundedSemaphore4Xi(value=1, maxvalue=2147483647)>,
        #             'rlock-of-queue2xi': <Lock(owner=None)>,
        #               'get-of-queue2xi': <bound method Queue4Xi.get of <queue4xi.Queue4Xi object at 0x02FD7370>>,
        #    notempty-notify-of-queue2xi': <bound method _Condition.notify of <Condition(<_thread.lock object at 0x02FA8550>, 1)>>,
        #                        'object': '<queue4xi.Queue4Xi object at 0x02FD7370>',
        #      'reader-close-of-queue2xi': <built-in method close of _multiprocessing.PipeConnection object at 0x02F73068>,
        #               'put-of-queue2xi': <bound method Queue4Xi.put of <queue4xi.Queue4Xi object at 0x02FD7370>>,
        #              'opid-of-queue2xi': 1664,
        #            'closed-of-queue2xi': False,
        #     'rlock-release-of-queue2xi': <built-in method release of _multiprocessing.SemLock object at 0x02FF1300>,
        #     'rlock-acquire-of-queue2xi': <built-in method acquire of _multiprocessing.SemLock object at 0x02FF1300>,
        #             'close-of-queue2xi': <finalize4xi: __repr__: Finalize object, callback=_finalize_close, args=[deque([]), <Condition(<_thread.lock object at 0x02FA8550>, 1)>],exitprority=10>, 
        #     'thread.daemon-of-queue2xi': True,
        #        'jointhread-of-queue2xi': None,
        #                'all-methods2xi': "['__class__', '__delattr__', '__eq__', '__format__', '__ge__', '__getattribute__', '__getstate__', '__gt__', '__hash__', '__init__', '__le__', '__lt__', '__ne__', '__new__', '__reduce__', '__reduce_ex__', '__repr__', '__setattr__', '__setstate__', '__sizeof__', '__str__', '__subclasshook__', '__weakref__', '_after_fork', '_close', '_feed', '_finalize_close', '_finalize_join', '_poll', '_recv', '_send', '_start_thread', 'ace', 'cancel_join_thread', 'close', 'empty', 'full', 'get', 'get_nowait', 'join_thread', 'put', 'put_nowait', 'qsize', 'reason', 'sense']", 
        #            'writer-of-queue2xi': <write-only PipeConnection, handle 416>,
        #      'buffer-clear-of-queue2xi': <built-in method clear of collections.deque object at 0x0302E0A0>
        #}                 
          
        return kb2xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
    #</methodize4xi>
    
        
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "reason-of-Queue4Xi" usage = "reasons Queue4Xi class objects">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def reason(self):
        '''
        method reason: reasons Queue4Xi class objects
        '''
                 
        
        class2print = 'Queue4Xi'
        method2print = 'reason'

        
        message2print = "{started" + "; reason-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
       
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{reasoning" + "; Queue4Xi-reasoning-by-reason-of-Queue4Xi: " + str(Queue4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print) 
                
        
        # -----------------------------------------------------------------------------------------
        # get reasoned knowledge for this object
        # -----------------------------------------------------------------------------------------         
        kb4xi = reason_object4xi(self)
        
        
        message2print = "{got" + "; knowledge-base4xi-got-by-reason-of-Queue4Xi: " + str(kb4xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                
        
        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb4xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------          
        
        
          
        
        message2print = "{reasoned" + "; Queue4Xi-reasoned-by-reason-of-Queue4Xi: " + str(Queue4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)       
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; knowledge-base4xi-returning-by-reason-of-Queue4Xi: " + str(kb4xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                               
          
        return kb4xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
    
    
    # ---------------------------------------------------------------------------------------------
    #<methodize4xi method = "ace-of-Queue4Xi" usage = "aces Queue4Xi class objects">
    #<state4xi status = "ACK4review; ACK4tagging; NACK4moduletesting; NACK4systemtesting"/>
    # ---------------------------------------------------------------------------------------------
    def ace(self):
        '''
        method ace: aces Queue4Xi class objects 
        '''

        class2print = 'Queue4Xi'
        method2print = 'ace'
        
        
        message2print = "{started" + "; ace-of-Queue4Xi-started: " + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)   
             
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------
        message2print = "{acing" + "; Queue4Xi-acing-by-ace-of-Queue4Xi: " + str(Queue4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)         
                     
        
        # -----------------------------------------------------------------------------------------
        # get aced knowledge for this object
        # -----------------------------------------------------------------------------------------        
        kb8xi = ace_object4xi(self)  
        
        message2print = "{got" + "; knowledge-base8xi-got-by-ace-of-Queue4Xi: " + str(kb8xi)  + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)
                


        # -----------------------------------------------------------------------------------------
        # add knowledge specific to this object
        # format example: kb8xi['time2xi'] = time4xi() #adding time 
        # -----------------------------------------------------------------------------------------              
        
          
        message2print = "{aced" + "; Queue4Xi-aced-by-ace-of-Queue4Xi: " + str(Queue4Xi) + "; time: " + time4xi() + "}"
        print4xi(class2print, method2print, message2print)           
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------        
        message2print = "{returning" + "; knowledge-base8xi-returning-by-ace-of-Queue4Xi: " + str(kb8xi) + "; time: " + time4xi() + "}" 
        print4xi(class2print, method2print, message2print)    
                             
        
        return kb8xi
        
        # -----------------------------------------------------------------------------------------
        #
        # -----------------------------------------------------------------------------------------            
    #</methodize4xi>
#</class4xi>
#</program4xi>


# -------------------------------------------------------------------------------------------------
# Recorded History                             
# ------------------------------------------------------------------------------------------------- 
#<record4xi record = "
#   test_math4xi.txt
#   sense-math4xi.xml
#   reason-math4xi.xml
#   ace-math4xi.xml
#
#   test_proxy_mp_xi4.py.txt
#   sense-proxy-mp-test4xi.xml
#   reason-proxy-mp-test4xi.xml
#   ace-proxy-mp-test4xi.xml
#"
#>

# -------------------------------------------------------------------------------------------------
# Legal Notice                             
# ------------------------------------------------------------------------------------------------- 
#<protect4xi protection = "copyright"
#   owner = "Small & Smart"
#   rights = "All rights reserved"
#   state = "California"
#   country = "United States of America"
#   references = "Legal notice at www.dragonxi.com; www.yourdragonxi.com; www.yourdragonxi.org; www.dragon2xi.com/; www.dragon4xi.com/; www.dragon8xi.com/ " 
#   codes = "Codes established in California and applicable to corporations in California"
#   compliance = "The California Law"
#   court = "Supreme Court of California, 350 McAllister Street, San Francisco, CA 94102-4783"
#/>

#<end4xi end = "
# -------------------------------------------------------------------------------------------------
# end of queue4xi.py                             
# ------------------------------------------------------------------------------------------------- 
#"
#/>
